#ifndef __INCTestEngineh
#define __INCTestEngineh

#ifndef COMMON__TYPES_H
typedef unsigned char  uint8;
typedef unsigned short uint16;
typedef signed short   int16;
typedef unsigned long int uint32;
#endif /* COMMON__TYPES_H */

#define BER_BIT_COUNT 0
#define BER_BIT_ERRORS 1
#define BER_ACCESS_CODE 2 /* Not used */
#define BER_RCVD_PKTS 3
#define BER_EXP_PKTS 4
#define BER_HDR_ERRORS 5
#define BER_CRC_ERRORS 6
#define BER_UNCORR_ERRORS 7
#define BER_SYNC_ERRORS 8
#define BER_MAX 9

#ifdef _WIN32
#define TESTENGINE_API(T) T _stdcall
#else
#define TESTENGINE_API(T) T
#endif

const int TE_INVALID_HANDLE = -1;
const int TE_ERROR = 0;
const int TE_OK = 1;
const int TE_UNSUPPORTED_FUNCTION = 2;

/* ERROR CODES - in the format returned by teGetLastError */
#define TE_ERROR_NONE                                                   0x000000
#define TE_ERROR_BCCMD_NO_SUCH_VARID                                    0x000001
#define TE_ERROR_BCCMD_DATA_EXCEEDED                                    0x000002
#define TE_ERROR_BCCMD_VAR_HAS_NO_VALUE                                 0x000003
#define TE_ERROR_BCCMD_BAD_VALUE                                        0x000004 
#define TE_ERROR_BCCMD_NO_ACCESS                                        0x000005
#define TE_ERROR_BCCMD_READ_ONLY                                        0x000006
#define TE_ERROR_BCCMD_WRITE_ONLY                                       0x000007
#define TE_ERROR_BCCMD_OTHER_ERROR                                      0x000008
#define TE_ERROR_BCCMD_PERMISSION_DENIED                                0x000009
#define TE_ERROR_TRANPSORT_ERROR                                        0x000100
#define TE_ERROR_HCI_UNKNOWN_COMMAND                                    0x010000
#define TE_ERROR_HCI_UNKNOWN_CONNECTION_ID                              0x020000
#define TE_ERROR_HCI_HARDWARE_FAILURE                                   0x030000
#define TE_ERROR_HCI_PAGE_TIMEOUT                                       0x040000
#define TE_ERROR_HCI_AUTHENTICATION_FAILURE                             0x050000
#define TE_ERROR_HCI_PIN_MISSING                                        0x060000
#define TE_ERROR_HCI_MEMORY_CAPACITY_EXCEEDED                           0x070000
#define TE_ERROR_HCI_CONNECTION_TIMEOUT                                 0x080000
#define TE_ERROR_HCI_CONNECTION_LIMIT_EXCEEDED                          0x090000
#define TE_ERROR_HCI_SYNCHRONOUS_CONNECTION_LIMIT_EXCEEDED              0x0a0000
#define TE_ERROR_HCI_ACL_CONNECTION_ALREADY_EXISTS                      0x0b0000
#define TE_ERROR_HCI_COMMAND_DISALLOWED                                 0x0c0000
#define TE_ERROR_HCI_CONNECTION_REJECTED_LIMITED_RESOURCES              0x0d0000
#define TE_ERROR_HCI_CONNECTION_REJECTED_SECURITY_REASONS               0x0e0000
#define TE_ERROR_HCI_CONNECTION_REJECTED_UNACCEPTABLE_BD_ADDR           0x0f0000
#define TE_ERROR_HCI_CONNECTION_ACCEPT_TIMEOUT_EXCEEDED                 0x100000
#define TE_ERROR_HCI_UNSUPPORTED_FEATURE                                0x110000
#define TE_ERROR_HCI_INVALID_COMMAND_PARAMETERS                         0x120000
#define TE_ERROR_HCI_REMOTE_USER_TERMINATED_CONNECTION                  0x130000
#define TE_ERROR_HCI_REMOTE_DEVICE_TERMINATED_CONNECTION_LOW_RESOURCES  0x140000
#define TE_ERROR_HCI_REMOTE_DEVICE_TERMINATED_CONNECTION_POWER_OFF      0x150000
#define TE_ERROR_HCI_CONNECTION_TERMINATED_BY_LOCAL_HOST                0x160000
#define TE_ERROR_HCI_REPEATED_ATTEMPTS                                  0x170000
#define TE_ERROR_HCI_PAIRING_NOT_ALLOWED                                0x180000
#define TE_ERROR_HCI_UNKNOWN_LMP_PDU                                    0x190000
#define TE_ERROR_HCI_UNSUPPORTED_REMOTE_FEATURE                         0x1a0000
#define TE_ERROR_HCI_SCO_OFFSET_REJECTED                                0x1b0000
#define TE_ERROR_HCI_SCO_INTERVAL_REJECTED                              0x1c0000
#define TE_ERROR_HCI_SCO_AIR_MODE_REJECTED                              0x1d0000
#define TE_ERROR_HCI_INVALID_LMP_PARAMETERS                             0x1e0000
#define TE_ERROR_HCI_UNSPECIFIED_ERROR                                  0x1f0000
#define TE_ERROR_HCI_UNSUPPORTED_LMP_PARAMETER_VALUE                    0x200000
#define TE_ERROR_HCI_ROLE_CHANGE_NOT_ALLOWED                            0x210000
#define TE_ERROR_HCI_LMP_RESPONSE_TIMEOUT                               0x220000
#define TE_ERROR_HCI_LMP_ERROR_TRANSACTION_COLLISION                    0x230000
#define TE_ERROR_HCI_LMP_PDU_NOT_ALLOWED                                0x240000
#define TE_ERROR_HCI_ENCRYPTION_MODE_NOT_ACCEPTABLE                     0x250000
#define TE_ERROR_HCI_LINK_KEY_CANNOT_BE_CHANGED                         0x260000
#define TE_ERROR_HCI_REQUESTED_QOS_NOT_SUPPORTED                        0x270000
#define TE_ERROR_HCI_INSTANT_PASSED                                     0x280000
#define TE_ERROR_HCI_PAIRING_WITH_UNIT_KEY_NOT_SUPPORTED                0x290000
#define TE_ERROR_HCI_DIFFERENT_TRANSACTION_COLLISION                    0x2a0000
#define TE_ERROR_HCI_RESERVED_1                                         0x2b0000
#define TE_ERROR_HCI_QOS_UNACCEPTABLE_PARAMETER                         0x2c0000
#define TE_ERROR_HCI_QOS_REJECTED                                       0x2d0000
#define TE_ERROR_HCI_CHANNEL_CLASSIFICATION_NOT_SUPPORTED               0x2e0000
#define TE_ERROR_HCI_INSUFFICIENT_SECURITY                              0x2f0000
#define TE_ERROR_HCI_PARAMETER_OUT_OF_MANDATORY_RANGE                   0x300000
#define TE_ERROR_HCI_RESERVED_2                                         0x310000
#define TE_ERROR_HCI_ROLE_SWITCH_PENDING                                0x320000
#define TE_ERROR_HCI_RESERVED_3                                         0x330000
#define TE_ERROR_HCI_RESERVED_SLOT_VIOLATION                            0x340000
#define TE_ERROR_HCI_ROLE_SWITCH_FAILED                                 0x350000

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/*************************************************************************************
    VERSION INFORMATION
*************************************************************************************/
/*************************************************************************************
    
    Function Name : int getTestEngineVersion(char * versionStr)

    Parameters :    
                versionStr - A pointer to a preallocated string that will have the
                    version string copied to it.

    Returns :        Always 1.

    Description :    Retrieve or displays the current version string.

*************************************************************************************/
TESTENGINE_API(int) getTestEngineVersion(char * versionStr);

/*************************************************************************************
    LINK MANAGEMENT FUNCTIONS
*************************************************************************************/

#define BCSP 0x1
#define USB 0x2
#define H4 0x4
#define H5 0x8

/*************************************************************************************
    
    Function Name : uint32 initTestEngine(int transport, char * transportDevice, unsigned long int dataRate, int usbTimeOut);

    Parameters :
                    transport - defines the protocol to be used when setting up the 
                                communication with BlueCore.
                                USB = 2
                                H4 = 4
                                BCSP = 1

                    transportDevice - Defines the physical port to use. A string which
                                for comm ports is "COMn" where 'n' is the number of the 
                                port. USB device names take the form "\\.\CSRn" where n
                                is the number of the port.
                                
                    dataRate - defines the baud rate to be used. For UART connections 
                                only.

                    usbTimeout - where transport = 2, this parameter will define the 
                                timeout to allow the USB device to ennumerate if it
                                has not already ennumerated. It has been found that some PC's 
                                take a longer time than expected to ennumerate a USB device and, 
                                in some cases, the PC's internal USB hub may have been reset 
                                which can cause a further delay in ennumeration. This parameter 
                                can be set to accomodate the extra time taken to reset USB devices.

    Returns :        This function will return a zero on failure or an unsigned integer which 
                    defines the handle to the host / host controller connection. This 
                    value is used as a parameter for all other function calls.

    Description :    An initTestEngine function has to called before any
                    communication with BlueCore can begin. 

*************************************************************************************/
TESTENGINE_API(uint32) initTestEngine(int transport, char * transportDevice, unsigned long int dataRate, int usbTimeOut);

/*************************************************************************************
    
    Function Name : uint32 initTestEngineSpi(int aPort, int aMulti, char aStopOnSpiAccess);

    Parameters :
                    aPort - Defines the physical port to use. Usually an LPT port
                            starting from 1.
                                
                    aMulti - A gate on a multi-spi interface

                    aStopOnSpiAccess - Flag defining whether the chip should be stopped
                          on SPI access.

    Returns :        This function will return a zero on failure or an unsigned integer which 
                    defines the handle to the host / host controller connection. This 
                    value is used as a parameter for all other function calls.

    Description :    An initTestEngine function has to be called before any
                    communication with BlueCore can begin. 
                    Note that over SPI transport the function set is limited to those
                    that use BCCMD. Commands not supported will return
                    TE_UNSUPPORTED_FUNCTION.

*************************************************************************************/
TESTENGINE_API(uint32) initTestEngineSpi(int aPort, int aMulti, char aStopOnSpiAccess);

/*************************************************************************************
    
    Function Name :    int closeTestEngine( uint32 handle);

    Parameters :
                    handle - handle to the device.

    Returns :        Always 1.

    Description :    This function should always be called when terminating 
                    communications with BlueCore. This function will NOT issue a reset.

                    
*************************************************************************************/
TESTENGINE_API(int) closeTestEngine( uint32 handle);

/*******************************************************************************
    
  Function Name : uint32 teGetLastError(uint32 handle);

  Parameters :
                  handle - handle to the device.

  Returns :       Last reported error code. If this value is zero then no error
                  was reported. A non-zero value signifies an error and the
                  value is decoded as follows:
                  <table>
                      <tr><td>Byte 1 (0x000000ff) = BCCMD error
                      <tr><td>Byte 2 (0x0000ff00) = Reserved
                      <tr><td>Byte 3 (0x00ff0000) = HCI / DM error
                      <tr><td>Byte 4 (0xff000000) = Reserved
                  </table>
                  BCCMD errors are defined as:
                  <table>
                      <tr><td>0 = No error
                      <tr><td>1 = BCCMD command ID not supported
                      <tr><td>2 = Data exceeded
                      <tr><td>3 = Variable ahs no value
                      <tr><td>4 = Get or set command held an error
                      <tr><td>5 = Value inaccessable
                      <tr><td>6 = Unwriteable
                      <tr><td>7 = Unreadable
                      <tr><td>8 = Other error
                      <tr><td>9 = Request not allowed
                  </table>
                  HCI / DM errors are defined in the Bluetooth specification.

  Description :   This function can be called to obtain a more detailed error
                  description when a TestEngine function fails.<br>
                  The return value of this function should not be relied upon
                  unless the preceding TestEngine function call returned 0 (for
                  failure).<br>
                  Error codes in the format returned by this function are 
                  defined at the top of TestEngine.h.
                    
*******************************************************************************/
TESTENGINE_API(uint32) teGetLastError(uint32 handle);

/*************************************************************************************
    
    Function Name : int bccmdSetColdReset( uint32 handle, int usbTimeout);

    Parameters :    
                    handle - handle to the device.

                    usbTimeout - where transport = 2, this parameter will define the 
                        timeout to allow the USB device to ennumerate if it
                        has not already ennumerated. It has been found that some PC's 
                        take a longer time than expected to ennumerate a USB device and, 
                        in some cases, the PC's internal USB hub may have been reset 
                        which can cause a further delay in ennumeration. This parameter 
                        can be set to accomodate the extra time taken to reset USB devices.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure.

    Description :    This command forces a hardware reset of BlueCore, deliberately 
                    discarding all of its current state - the command emulates removing 
                    power from the chip, then restoring it. It will attempt to 
                    reinitialise communication using the same transport settings as 
                    declared in initTestEngine(..). If the reset or the 
                    re-establishment fails the objects associated with the 
                    communication stack will be deleted.

*************************************************************************************/
TESTENGINE_API(int) bccmdSetColdReset( uint32 handle, int usbTimeout);

/*************************************************************************************
    
    Function Name : int bccmdSetWarmReset( uint32 handle, int usbTimeout);

    Parameters :    
                    handle - handle to the device.

                    usbTimeout - where transport = 2, this parameter will define the 
                        timeout to allow the USB device to ennumerate if it
                        has not already ennumerated. It has been found that some PC's 
                        take a longer time than expected to ennumerate a USB device and, 
                        in some cases, the PC's internal USB hub may have been reset 
                        which can cause a further delay in ennumeration. This parameter 
                        can be set to accomodate the extra time taken to reset USB devices.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure.

    Description :    This forces a hardware reset of the BlueCore, arranging that 
                    some elements of the chips current state may be available when 
                    the chip is restarted, assuming the chip remains powered through 
                    the reset. It will then attempt to reinitialise communication 
                    using the same transport settings as declared in 
                    initTestEngine(). If the reset or the re-establishment fails the 
                    objects associated with the communication stack will be deleted.

*************************************************************************************/
TESTENGINE_API(int) bccmdSetWarmReset( uint32 handle, int usbTimeout);

/*************************************************************************************
    MISC. TESTS
*************************************************************************************/

/*************************************************************************************
    
    Function Name :    int radiotestPause( uint32 handle);

    Parameters :    handle - handle to the device
    
    Returns :        -1 on invalid handle, 1 on success, 0 on failure.

    Description :    This function will cause any tests running to terminate.

*************************************************************************************/
TESTENGINE_API(int) radiotestPause( uint32 handle);

/*************************************************************************************
    
    Function Name :    int radiotestDeepSleep(uint32 handle);

    Parameters :    handle - handle to the device
    
    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will cause the DUT to enter deep sleep.

*************************************************************************************/
TESTENGINE_API(int) radiotestDeepSleep(uint32 handle);

/*************************************************************************************
    
    Function Name :    int radiotestPcmExtLb(uint32 handle, uint16 pcm_mode);

    Parameters :    handle - handle to the device

                    pcm_mode - can be
                    <table>
                        <tr><td>0  Slave in normal 4-wire configuration
                        <tr><td>1  Master in normal 4-wire configuration
                        <tr><td>2  Master in Alcatel-specific 2-wire configuration
                    </table>
    
    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This command enables PCM external loopback test mode in which a 
                    block of random data is written to the PCM output port and is read 
                    back again on the PCM input port. A check is made that the data 
                    matches. External wiring must be provided between the corresponding 
                    pins. The pcm_mode parameter can take the following values:
                        0 Slave in normal four-wire configuration
                        1 Master in normal four-wire configuration
                        2 Master in Manchester encoded, two-wire configuration
                    For a normal loopback configuration pcm_mode should be 1.

*************************************************************************************/
TESTENGINE_API(int) radiotestPcmExtLb(uint32 handle, uint16 pcm_mode);

/*************************************************************************************
    
    Function Name :    int radiotestPcmLb(uint32 handle, uint16 pcm_mode);

    Parameters :    handle - handle to the device

                    pcm_mode - can be
                    <table>
                        <tr><td>0  Slave in normal 4-wire configuration
                        <tr><td>1  Master in normal 4-wire configuration
                        <tr><td>2  Master in Alcatel-specific 2-wire configuration
                    </table>

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This command enables PCM LOOPBACK test mode in which data read from 
                    the PCM input port is written back out again via the pulse code 
                    modulation (PCM) output port after a delay. The pcm_mode parameter 
                    can take the following values:
                        0 Slave in normal 4-wire configuration
                        1 Master in normal 4-wire configuration
                        2 Master in Manchester encoded, 2-wire configuration
                    For a normal loopback configuration pcm_mode should be 1.

*************************************************************************************/
TESTENGINE_API(int) radiotestPcmLb(uint32 handle, uint16 pcm_mode);

/*************************************************************************************
    
    Function Name :    int radiotestPcmTimingIn(uint32 handle, uint16 pio_out, uint16 pcm_in);

    Parameters :    handle - handle to the device

                    pio_out - 0 to 7, PIO pin used for writing

                    pcm_in - 0 to 1, PCM pin used for reading
    
    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This command is similar to PCM_EXT_LB: this makes a series of 
                    writes to a PIO pin and tests that the result is readable on one 
                    of the PCM pins used for timing in slave mode, PCM_SYNC and PCM_CLK. 
                    A check is made that the data matches. External wiring must be 
                    provided between the corresponding pins. The pio_out parameter can 
                    take the values 0 to 7, corresponding to the PIO pin to be used 
                    for output. The pcm_in parameter can take the following values:
                        0 Test input on PCM_SYNC
                        1 Test input on PCM_CLK

*************************************************************************************/
TESTENGINE_API(int) radiotestPcmTimingIn(uint32 handle, uint16 pio_out, uint16 pcm_in);

/*************************************************************************************
    
    Function Name :    int radiotestPcmTone(uint32 handle, uint16 freq, uint16 ampl, uint16 dc);

    Parameters :    handle - handle to the device

                    freq - controls the frequency of the sine wave. The value 0 
                        corresponds to 250Hz; each increment of 1 doubles the frequency. 
                        Hence, 1 corresponds to 500Hz, 2 to 1kHz and so on. No bounds 
                        checking is performed on the parameter, but large values will 
                        not be useful owing to hardware limitations.

                    ampl - controls the amplitude of the sine wave. 8 is the full 
                        volume; each decrement of 1 reduces the amplitude by a factor 
                        of 2. 0 is valid and causes the hardware to be activated with 
                        constant audio data.

                    dc - constant offset to be added to the audio data.
    
    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This command enables PCM external loopback test mode in which a 
                    block of random data is written to the PCM output port and is read 
                    back again on the PCM input port. A check is made that the data 
                    matches. External wiring must be provided between the corresponding 
                    pins. The pcm_mode parameter can take the following values:
                        0 Slave in normal four-wire configuration
                        1 Master in normal four-wire configuration
                        2 Master in Manchester encoded, two-wire configuration
                    For a normal loopback configuration pcm_mode should be 1.

*************************************************************************************/
TESTENGINE_API(int) radiotestPcmTone(uint32 handle, uint16 freq, uint16 ampl, uint16 dc);

/*************************************************************************************
    
    Function Name :    int radiotestCtsRtsLb(uint32 handle);

    Parameters :    handle - handle to the device

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This command performs a series of writes to the UART CTS (clear to 
                    send) line and attempts to read back the value written on the UART 
                    RTS (ready to send) line. External wiring must be provided between 
                    the corresponding pins.

*************************************************************************************/
TESTENGINE_API(int) radiotestCtsRtsLb(uint32 handle);

/*************************************************************************************
    
    Function Name :    int radiotestRadioStatus(uint32 handle);

    Parameters :    handle - handle to the device

    Returns :        -1 on invalid handle, 1 on success, 0 on failure, 2
                    if not supported over the current connection.

    Description :    This function will send request BlueCore to send the current radio 
                    status information. Once the command is issued BlueCore will need 
                    to be polled for the status using the hqGetRadioStatus(..) function.
                    <p>This function is not supported over a SPI connection.

                
*************************************************************************************/
TESTENGINE_API(int) radiotestRadioStatus(uint32 handle);

/*************************************************************************************
    
    Function Name :    int hqGetRadioStatus(uint32 handle, uint16 * r, int timeout)

    Parameters :    handle - handle to the device

                    r - pointer to an array of 7 unsigned 16-bit integers. These will 
                        be used to store the radio status array as follows:
                        <table>
                        <tr><td>Index Parameter<td>Type of Status Report
                        <tr><td>0    <td>Internal transmission level
                        <tr><td>1    <td>External transmission level
                        <tr><td>2    <td>Reception level
                        <tr><td>3    <td>Local oscillator level
                        <tr><td>4    <td>IQ trim
                        <tr><td>5    <td>Signal to image ratio in dB
                        <tr><td>6    <td>Receivers attenuation
                        <tr><td>7    <td>Local oscillator amplitude (LO_AMPL) used for table look-up
                        </table>

                    timeout - Used to specify a timeout, in ms, which the software will 
                        wait for the HQ radio status packet to be returned from BlueCore.

    Description :    This function will wait for a time period specified by "timeout" 
                    for the HQ radio status packet.
                
*************************************************************************************/
TESTENGINE_API(int) hqGetRadioStatus(uint32 handle, uint16 * r, int timeout);

/*************************************************************************************
    
    Function Name :    int bccmdGetBuildId(uint32 handle, uint16 * buildid);

    Parameters :    handle - handle to the device

                    buildid - pointer to a variable to hold the returned firmware build ID

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will return the firmware's build ID

*************************************************************************************/
TESTENGINE_API(int) bccmdGetBuildId(uint32 handle, uint16 * buildid);

/*************************************************************************************
    
    Function Name :    int bccmdGetChipVersion(uint32 handle, uint16 * chipver);

    Parameters :    handle - handle to the device

                    chipver - pointer to a variable to hold the returned chip version

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will return the chip major version number

*************************************************************************************/
TESTENGINE_API(int) bccmdGetChipVersion(uint32 handle, uint16 * chipver);

/*************************************************************************************
    
    Function Name :    int bccmdGetChipRevision(uint32 handle, uint16 * chiprev);

    Parameters :    handle - handle to the device

                    chiprev - pointer to a variable to hold the returned chip revision.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will return the chip revision number

*************************************************************************************/
TESTENGINE_API(int) bccmdGetChipRevision(uint32 handle, uint16 * chiprev);

/*************************************************************************************
    
    Function Name :    int bccmdGetInterfaceVersion(uint32 handle, uint16 * interfaceVersion);

    Parameters :    handle - handle to the device

                    interfaceVersion - pointer to a variable to hold the returned 
                        BCCMD interface version.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will return the firmware BCCMD interface version.

*************************************************************************************/
TESTENGINE_API(int) bccmdGetInterfaceVersion(uint32 handle, uint16 * interfaceVersion);

/*************************************************************************************
    
    Function Name :    int bccmdGetRadiotestInterfaceVersion(uint32 handle, uint16 * interfaceVersion);

    Parameters :    handle - handle to the device

                    interfaceVersion - pointer to a variable to hold the returned 
                        radiotest interface version.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will return the firmware radiotest BCCMD interface 
                    version.

*************************************************************************************/
TESTENGINE_API(int) bccmdGetRadiotestInterfaceVersion(uint32 handle, uint16 * interfaceVersion);

/*******************************************************************************
    
  Function Name : int bccmdRouteClock(uint32 handle);

  Parameters :    aHandle - Handle to the BlueCore device.

  Returns :       -1 on invalid handle, 1 on success, 0 on failure.

  Description :   This function is used to issue a BCCMDVARID_ROUTE_CLOCK to
                  the connected BlueCore device.<br>
                  On supported firmware this will route the clock to AIO1.<br>
                  The device must be reset with the bccmdSetColdReset function
                  to stop the clock signal being routed to the AIO pin.

*******************************************************************************/
TESTENGINE_API(int) bccmdRouteClock(uint32 aHandle);

/*************************************************************************************
    
    Function Name :    int bccmdSetPio(uint32 handle, uint16 mask, uint16 port);

    Parameters :    handle - handle to the device

                    mask - read / write bit mask of PIO port.
                    
                    port - bit settings of PIO port.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will set the pio port.

*************************************************************************************/
TESTENGINE_API(int) bccmdSetPio(uint32 handle, uint16 mask, uint16 port);

/*************************************************************************************
    
    Function Name :    int bccmdGetPio(uint32 handle, uint16 * mask, uint16 * port);

    Parameters :    handle - handle to the device

                    mask - read / write bit mask of PIO port.
                    
                    port - bit settings of PIO port.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will get the pio port.

*************************************************************************************/
TESTENGINE_API(int) bccmdGetPio(uint32 handle, uint16 * mask, uint16 * port);

/*************************************************************************************
    
    Function Name :    int bccmdGetAio(uint32 handle, uint16 aio, uint16 * result);

    Parameters :    handle - handle to the device

                    aio - AIO pin which will be read 0 to 3.
                    
                    result - reference to 32 bit unsigned int, holds the result of the 
                    ADC voltage reading. This value is from 0 to 255 where 0 = 0V and 
                    255 = VDD Therefore:
                        <p>voltage_reading = (result/255)*(VDD)

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will perform a voltage reading on the specified AIO
                    pin.

*************************************************************************************/
TESTENGINE_API(int) bccmdGetAio(uint32 handle, uint16 aio, uint16 * result);

/*************************************************************************************
    
    Function Name :    int bccmdGetFirmwareCheckMask(uint32 handle, uint16 * mask);

    Parameters :    handle - handle to the device

                    mask - pointer to mask which states which firmware component is 
                        present AND if that component contains a pre-calculated checksum.
                        <table>
                        <tr><td>Bit    <td>Component
                        <tr><td>0    <td>Stack
                        <tr><td>1    <td>Loader
                        <tr><td>3    <td>VM application
                        </table>
                    
    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will check if each firmware component is present and 
                    that it contains a valid checksum. This function should be called 
                    before bccmdGetFirmwareCheck.

*************************************************************************************/
TESTENGINE_API(int) bccmdGetFirmwareCheckMask(uint32 handle, uint16 * mask);

/*************************************************************************************
    
    Function Name :    int bccmdGetFirmwareCheck(uint32 handle, uint16 * check);

    Parameters :    handle - handle to the device

                    check - pointer to a mask which states which firmware component is 
                        present AND if that component contains the correct checksum
                        <table>
                        <tr><td>Bit    <td>Component
                        <tr><td>0    <td>Stack
                        <tr><td>1    <td>Loader
                        <tr><td>3    <td>VM application
                        </table>
                    
    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will check if each firmware component checksum is correct.

*************************************************************************************/
TESTENGINE_API(int) bccmdGetFirmwareCheck(uint32 handle, uint16 * check);

/*************************************************************************************
    
  Function Name : int bccmdEnableDeviceUnderTestMode(uint32 handle);

  Parameters :    handle - handle to the device

  Returns :       -1 on invalid handle, 1 on success, 0 on failure

  Description :   Causes the device to send the enable device under test mode
                  BCCMD PDU.
                  Success is determined by:
                  <ol>
                  <li> Valid handle
                  <li> Command complete within timeout
                  </ol>

*************************************************************************************/
TESTENGINE_API(int) bccmdEnableDeviceUnderTestMode(uint32 handle);

/*************************************************************************************
    TRANSMITTER TESTS
*************************************************************************************/

/*************************************************************************************
    
 Function Name : int radiotestStereoCodecLB(uint32 aHandle, uint16 aSampleRate, uint16 aReroute);

 Parameters :    aHandle - Handle to the device.

                 aSampleRate - Sample rate in Hz.

                 aReroute - Controls how signal is routed from mic to speaker.
                 <table>
                 <tr><td>0 - <td>MicL to SpkL, MicR to SpkR
                 <tr><td>1 - <td>MicR to SpkL and SpkR
                 <tr><td>2 - <td>MicL to SpkL and SpkR
                 <tr><td>3 - <td>MicL to SpkR, MicR to SpkL
                 </table>

 Returns :       -1 on invalid handle, 1 on success, 0 on failure.

 Description :   This function is used to turn on the codec hardware for stereo
                 loopback.

*************************************************************************************/
TESTENGINE_API(int) radiotestStereoCodecLB(uint32 aHandle, int aSampleRate, uint16 aReroute);

/*************************************************************************************
    
    Function Name :    int radiotestTxstart(uint32 handle, uint16 frequency, uint16 intPA, uint16 extPA, int16 modulation);

    Parameters :    handle - handle to the device.

                    frequency - Local Oscillator frequency

                    intPA - Drive level for internal PA (0 to 63)

                    extPA - Drive level for external PA

                    modulation - modulation offset - 4096 = 1MHz
    
    Returns :        -1 on invalid handle, 1 on success, 0 on failure.

    Description :    This function initiates TXSTART

*************************************************************************************/
TESTENGINE_API(int) radiotestTxstart(uint32 handle, uint16 frequency, uint16 intPA, uint16 extPA, int16 modulation);

/*************************************************************************************
    
    Function Name :    int radiotestTxdata1( uint32 handle, uint16 frequency, uint16 intPA, uint16 extPA);

    Parameters :    handle - handle to the device

                    frequency - Local Oscillator frequency

                    intPA - Drive level for internal PA (0 to 63)

                    extPA - Drive level for external PA

    Returns :        -1 on invalid handle, 1 on success, 0 on failure.

    Description :    This function initiates TXDATA1

*************************************************************************************/
TESTENGINE_API(int) radiotestTxdata1(uint32 handle, uint16 frequency, uint16 intPA, uint16 extPA);

/*************************************************************************************
    
    Function Name :    int radiotestTxdata2(uint32 handle, uint16 countrycode, uint16 intPA, uint16 extPA);

    Parameters :    handle - handle to the device

                    countrycode - Country code for hopping sequence

                    intPA - Drive level for internal PA (0 to 63)

                    extPA - Drive level for external PA

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function initiates TXDATA2

*************************************************************************************/
TESTENGINE_API(int) radiotestTxdata2(uint32 handle, uint16 countrycode, uint16 intPA, uint16 extPA);

/*************************************************************************************
    
    Function Name :    int radiotestTxdata3(uint32 handle, uint16 frequency, uint16 intPA, uint16 extPA);

    Parameters :    handle - handle to the device

                    frequency - Local Oscillator frequency

                    intPA - Drive level for internal PA (0 to 63)

                    extPA - Drive level for external PA

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function initiates TXDATA3

************************************************************************************/
TESTENGINE_API(int) radiotestTxdata3(uint32 handle, uint16 frequency, uint16 intPA, uint16 extPA);

/*************************************************************************************
    
    Function Name :    int radiotestTxdata4(uint32 handle, uint16 frequency, uint16 intPA, uint16 extPA);

    Parameters :    handle - handle to the device

                    frequency - Local Oscillator frequency

                    intPA - Drive level for internal PA (0 to 63)

                    extPA - Drive level for external PA

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function initiates TXDATA4

*************************************************************************************/
TESTENGINE_API(int) radiotestTxdata4(uint32 handle, uint16 frequency, uint16 intPA, uint16 extPA);

/*************************************************************************************
    RECIEVER TESTS
*************************************************************************************/
/*************************************************************************************
    
    Function Name :    int radiotestRxstart1(uint32 handle, uint16 frequency, int hiside, uint16 rx_attenuation);

    Parameters :    handle - handle to the device

                    frequency - Local Oscillator frequency in MHz. Should be in
                       the range 2402 to 2480.

                    hiside - Set to 0 for low side modulation and 1 for high
                       side modulation.

                    rx_attenuation - Attenuation setting. Should be in the range
                       0 to 15.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure, 2
                    if not supported over the current connection.

    Description :    This function initiates RXSTART1.<p>
                    Enables the receiver in continuous reception at a designated
                    frequency (LO Freq) with a choice of low or high side
                    modulation (hi-side) and with a designated attenuation
                    setting (RX Attenuation).
                    <p>Requires a second unit to be running TXSTART.
                    <p>This function is not supported over a SPI connection.

*************************************************************************************/
TESTENGINE_API(int) radiotestRxstart1(uint32 handle, uint16 frequency, int hiside, uint16 rx_attenuation);

/*************************************************************************************
    
    Function Name :    int radiotestRxstart2(uint32 handle, uint16 frequency, int hiside, uint16 rx_attenuation, int sample_size);

    Parameters :    handle - handle to the device

                    frequency - Local Oscillator frequency in MHz. Should be in
                       the range 2402 to 2480.

                    hiside - Set to 0 for low side modulation and 1 for high
                       side modulation.

                    rx_attenuation - Attenuation setting. Should be in the range
                       0 to 15.

                    sample_size - Number of RSSI reports that will be averaged to 
                        achieve the final RSSI value.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure, 2
                    if not supported over the current connection.

    Description :    This function initiates RXSTART2.<p>
                    Enables the receiver in continuous reception, at a
                    designated frequency (LO Freq), with a choice of low or
                    high side modulation (hi-side) and with a designated
                    attenuation setting (RX Attenuation).
                    <p>Requires a second unit to be running TXSTART.
                    <p>This function is not supported over a SPI connection.

*************************************************************************************/
TESTENGINE_API(int) radiotestRxstart2(uint32 handle, uint16 frequency, int hiside, uint16 rx_attenuation, int sample_size);

/*************************************************************************************
    
    Function Name :    int hqGetRssi(uint32 handle, int timeout, int max_size, uint16 * r);

    Parameters :    handle - handle to the device
                    
                    timeout - time, in ms, which the function will wait for valid results. 
                        If set to zero the function will just check for completion.

                    max_size - size of the array allocated to hold the RSSI samples

                    r - Array containing the RSSI samples

    Return :        -1 on invalid handle, 0 on failure, sample_size or max_size on success.

    Description :    This function obtains the last complete RSSI results from 
                    BlueCore. The results are collected by calling do_rxstart2.

*************************************************************************************/
TESTENGINE_API(int) hqGetRssi(uint32 handle, int timeout, int max_size, uint16 * r);

/*************************************************************************************
    
    Function Name :    int radiotestBer1(uint32 handle, uint16 frequency, int hiside, uint16 rx_attenuation, uint32 sampleSize);

    Parameters :    handle - handle to the device

                    frequency - Local Oscillator frequency in MHz. Should be in
                       the range 2402 to 2480.

                    hiside - Set to 0 for low side modulation and 1 for high
                       side modulation.

                    rx_attenuation - Attenuation setting. Should be in the range
                       0 to 15.

                    sampleSize - Number of bits to be sampled.

    Returns :        -1 on invalid handle, 0 on failure, 1 on success, 2
                    if not supported over the current connection.

    Description :    This function initiates BER1.<p>
                    Enables the receiver at a designated frequency (LO Freq)
                    with a choice of low or high side modulation (hi-side) and
                    with a designated attenuation setting (RX Attenuation).
                    <p>This function is not supported over a SPI connection.

*************************************************************************************/
TESTENGINE_API(int) radiotestBer1(uint32 handle, uint16 frequency, int hiside, uint16 rx_attenuation, uint32 sampleSize);

/*************************************************************************************
    
    Function Name :    int radiotestBer2(uint32 handle, uint16 country_code, int hiside, uint16 rx_attenuation, uint32 sampleSize);

    Parameters :    handle - handle to the device

                    country_code - Valid country code

                    hiside - Set to 0 for low side modulation and 1 for high
                       side modulation.

                    rx_attenuation - Attenuation setting. Should be in the range
                       0 to 15.

                    sampleSize - Number of bits to be sampled.

    Returns :        -1 on invalid handle, 0 on failure, 1 on success, 2
                    if not supported over the current connection.

    Description :    This function initiates BER2.<p>
                    Enables the receiver with simplified hopping defined by
                    a country code with a choice of low or high side modulation
                    (hi-side), and with a designated attenuation setting (RX
                    Attenuation) as for radiotestRxdata2.
                    <p>This function is not supported over a SPI connection.

*************************************************************************************/
TESTENGINE_API(int) radiotestBer2(uint32 handle, uint16 country_code, int hiside, uint16 rx_attenuation, uint32 sampleSize);

/*************************************************************************************
    
    Function Name :    int radiotestBerLoopback(uint32 handle, uint16 frequency, uint16 intPA, uint16 extPA, uint32 sampleSize);

    Parameters :    handle - handle to the device

                    frequency - Local Oscillator frequency

                    intPA - Drive level for internal PA (0 to 63)

                    extPA - Drive level for external PA

                    sampleSize - Number of bits to be sampled.

    Returns :        -1 on invalid handle, 0 on failure, 1 on success, 2
                    if not supported over the current connection.

    Description :    This function initiates BER_LOOPBACK
                    <p>This function is not supported over a SPI connection.

*************************************************************************************/
TESTENGINE_API(int) radiotestBerLoopback(uint32 handle, uint16 frequency, uint16 intPA, uint16 extPA, uint32 sampleSize);

/*************************************************************************************
    
    Function Name :    int radiotestLoopback(uint32 handle, uint16 frequency, uint16 intPA, uint16 extPA);

    Parameters :    handle - handle to the device

                    frequency - Local Oscillator frequency

                    intPA - Drive level for internal PA (0 to 63)

                    extPA - Drive level for external PA

    Returns :        -1 on invalid handle, 0 on failure, 1 on success

    Description :    This function initiates LOOPBACK

*************************************************************************************/
TESTENGINE_API(int) radiotestLoopback(uint32 handle, uint16 frequency, uint16 intPA, uint16 extPA);

/*************************************************************************************
    
    Function Name :    int hqGetBer( uint32 handle, int timeout, uint32 * r);

    Parameters :    handle - handle to the device
                    
                    timeout - time, in ms, which the function will wait for valid results. 
                        If set to zero the function will just check for completion.

                    r - Array containing culmative BER report. Defined as follows:
                    <table>
                    <tr><td>r[0] = cumulative bit count
                    <tr><td>r[1] = cumulative bit errors
                    <tr><td>r[2] = NOT USED
                    <tr><td>r[3] = cumulative recieved packets
                    <tr><td>r[4] = cumulative expected packets
                    <tr><td>r[5] = cumulative header errors
                    <tr><td>r[6] = cumulative CRC errors
                    <tr><td>r[7] = cumulative uncorrected errors
                    <tr><td>r[8] = cumulative sync errors
                    </table>

    Return :        -1 on invalid handle, 0 on failure, BER_MAX on success.

    Description :    This function obtains the last complete BER results samlpe from 
                    BlueCore.

*************************************************************************************/
TESTENGINE_API(int) hqGetBer( uint32 handle, int timeout, uint32 * r);

/*************************************************************************************
    
    Function Name :    int radiotestRxdata1(uint32 handle, uint16 frequency, int hiside, uint16 rx_attenuation);

    Parameters :    handle - Handle to the device.

                    frequency - Local Oscillator (LO) frequency in MHz. Should
                       be in the range 2402 to 2480.

                    hiside - Set to 0 for low side modulation or 1 for high
                       side modulation.

                    rx_attenuation - Attenuation setting. Should be in the
                       range 0 to 15.

    Returns :        -1 on invalid handle, 0 on failure, BER_MAX on success, 2
                    if not supported over the current connection.

    Description :    Enables the receiver, at a designated frequency (LO Freq)
                    with a choice of low or high side modulation (hi-side), and
                    with a designated attenuation setting (RX Attenuation).
                    The software counts the number of received packets and the
                    number of payloads with correctable errors.
                    <p>This function is not supported over a SPI connection.

*************************************************************************************/
TESTENGINE_API(int) radiotestRxdata1(uint32 handle, uint16 frequency, int hiside, uint16 rx_attenuation);

/*************************************************************************************
    
    Function Name :    int radiotestRxdata2(uint32 handle, uint16 countrycode, int hiside, uint16 rx_attenuation);

    Parameters :    handle - Handle to the device.

                    countrycode - Country code to determine hop sequence. Should
                       be in the range 0 to 3.

                    hiside - Set to 0 for low side modulation or 1 for high
                       side modulation.

                    rx_attenuation - Attenuation setting. Should be in the
                       range 0 to 15.

    Returns :        -1 on invalid handle, 0 on failure, BER_MAX on success, 2
                    if not supported over the current connection.

    Description :    Enables the receiver with a simplified hop sequence
                    designated by a country code, with a choice of low or high
                    side modulation (hi-side) and with a designated attenuation
                    setting (RX Attenuation).
                    The software counts the number of received packets and the
                    number of payloads with correctable errors.
                    <p>This function is not supported over a SPI connection.

*************************************************************************************/
TESTENGINE_API(int) radiotestRxdata2(uint32 handle, uint16 countrycode, int hiside, uint16 rx_attenuation);

/*************************************************************************************
    
    Function Name :    int hqGetRxdata(uint32 handle, uint16 * r);

    Parameters :    handle - handle to the device

                    r - Pointer to an array which will receive the following:
                    <table>
                    <tr><td> r[0] = Number of packets received
                    <tr><td> r[1] = Number of good packets
                    <tr><td> r[2] = Number of corrected packets
                    <tr><td> r[3] = RSSI value
                    <tr><td> r[4] = Boolean flag showing if RSSI value is valid.
                    </table>

    Returns :        -1 on invalid handle, 0 on failure, array size on success

    Description :    This function will return the last packet generated by either 
                    RXDATA1 or RXDATA2. Once the packet has been read it cannot be 
                    read again until the next packet is generated.

*************************************************************************************/
TESTENGINE_API(int) hqGetRxdata( uint32 handle, uint16 * r);

/*************************************************************************************
    CONFIGURATION COMMANDS
*************************************************************************************/
/*************************************************************************************
    
    Function Name :    int radiotestCfgFreq(uint32 handle, uint16 txrxinterval, uint16 loopback, uint16 report);

    Parameters :    handle - handle to the device

                    txrxinterval - sets the period in microseconds between TX and RX 
                        events in RXDATA, TXDATA, BIT ERR and LOOP BACK test modes. 
                        Default is 1250 (20 slots), maximum 65536. If passed as 0, 
                        current value unchanged.
                    
                    loopback - Sets the offset in microseconds between a reception 
                        event and retransmission of the data in loopback. Default is 
                        1875 (two slots later), must be less than txrxinterval. If 
                        passed as zero current value unchanged.

                    report - Sets the time in seconds between reports to host sent by 
                        RXDATA and BIT ERR functions. Default 1, if passed as 0 
                        current value unchanged.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Sets three values used in deciding timing details of tests.

*************************************************************************************/
TESTENGINE_API(int) radiotestCfgFreq(uint32 handle, uint16 txrxinterval, uint16 loopback, uint16 report);

/*************************************************************************************
    
    Function Name :    int radiotestCfgPkt(uint32 handle, uint16 type, uint16 size);

    Parameters :    handle - handle to the device

                    type - The standard Bluetooth packet type, 0-15 (12-13 not 
                        allowed). Any other number sets default: 
                        <table>
                        <tr><td> DM5 for TXDATA1/2
                        <tr><td> DH5 for TXDATA3/4
                        </table>

                    size - The size of data in packet, from one to maximum for type. 
                        If zero sets default: 
                        <table>
                        <tr><td> 20 bytes for TXDATA1/2
                        <tr><td> 192 bytes for TXDATA3/4.
                        </table>

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Sets packet type and size for transmitter tests. It has no effect 
                    on RX or LOOP BACK tests.

*************************************************************************************/
TESTENGINE_API(int) radiotestCfgPkt(uint32 handle, uint16 type, uint16 size);

/*************************************************************************************
    
    Function Name :    int radiotestCfgBitError(uint32 handle, uint32 sampleSize, int reset);

    Parameters :    handle - Handle to the device

                    sampleSize - If non-zero, the target for total counters is set to 
                        this and total count resets at this value. If passed as 0 
                        current value, unchanged. 
                    
                    reset - If not false and BIT ERR/2 is active, immediately resets
                        the counters for the total statistics, but not over the last 
                        report period.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Sets two values used in bit error measurements.

*************************************************************************************/
TESTENGINE_API(int) radiotestCfgBitError(uint32 handle, uint32 sampleSize, int reset);

/*************************************************************************************
    
    Function Name :    int radiotestCfgXtalFtrim(uint32 handle, uint16 ftrim);

    Parameters :    handle - Handle to the device

                    ftrim - A number between 0 and 63 inclusive. This is not a 
                        permanent change.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Timing for BlueCore01 is controlled by a crystal. This requires
                    trimming for new hardware. This command can be used to set a new 
                    trim value either before a radiotest command is started or while 
                    a test is already in operation; the change takes effect 
                    immediately.

*************************************************************************************/
TESTENGINE_API(int) radiotestCfgXtalFtrim(uint32 handle, uint16 ftrim);

/*************************************************************************************
    
    Function Name : int radiotestCfgUapLap(uint32 handle, uint16 uap, uint32 lap);

    Parameters :    handle - Handle to the device.

                    uap - UAP portion of the device address (0 to 0xff).

                    lap - LAP portion of the device address (0 to 0xffffff).

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :   Sets the UAP and LAP to be used in radio tests. BlueCore
                    usually uses its own Bluetooth Device address to determine
                    the access sync code, as if it is master of a piconet.
                    The UAP and LAP are the only parts used.

*************************************************************************************/
TESTENGINE_API(int) radiotestCfgUapLap(uint32 handle, uint16 uap, uint32 lap);

/*************************************************************************************
    
    Function Name :    int radiotestCfgIqTrim(uint32 handle, uint16 trim);

    Parameters :    handle - Handle to the device

                    trim - Value to be written to the register, ANA_IQ_TRIM.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    The IQ block may be trimmed by setting a register, ANA_IQ_TRIM.
                    This allows the variable to be set for the test modes.  The value
                    "trim", 0 to 511 inclusive, takes effect immediately, is not 
                    saved, and must be reset on each test, as the IQ is calibrated at 
                    the start.

*************************************************************************************/
TESTENGINE_API(int) radiotestCfgIqTrim(uint32 handle, uint16 trim);

/*************************************************************************************
    
    Function Name :    int radiotestCfgTxIf(uint32 handle, int16 offset);

    Parameters :    handle - handle to the device

                    offset - value to be written to the register, ANA_IQ_TRIM.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    The bc01 transmitter uses an additional offset in the IF part of 
                    the transmitter, which needs to be configured for optimum 
                    performance. The target is to be able to set this to zero. 
                    However, the stack currently uses an offset of 1MHz 1.5MHz.
                    "offset_half_mhz" sets the value of this in units of 0.5MHz for 
                    the radiotests. The default is the value used in standard 
                    operation, currently 3 units, i.e. 1.5MHz offset.  Note this is a 
                    signed integer.  The range is -5 to +5. This must be set before 
                    the start of a radio transmitter test.

*************************************************************************************/
TESTENGINE_API(int) radiotestCfgTxIf(uint32 handle, int16 offset);

/*************************************************************************************
    
    Function Name :    int radiotestCfgTxTrim(uint32 handle, uint16 am_addr);

    Parameters :    handle - handle to the device

                    am_addr - active member address.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Sets the AM_ADDR used in the header of test transmissions, and
                    expected in receiving test transmissions.  It is a number between 
                    0 and 7, inclusive.  The default value is 7.  This takes effect
                    immediately and lasts until a new test is restarted, at which
                    point a default read from persistent store is used.  The defaults
                    are: PSKEY_RADIOTEST_TX_TRIM1 for PRBS data (which is assumed
                    for all reception routines), PSKEY_RADIOTEST_TX_TRIM2 for alternating
                    bits (1010...), PSKEY_RADIOTEST_TX_TRIM3 for alternating nybbles
                    (11110000).

*************************************************************************************/
TESTENGINE_API(int) radiotestCfgTxTrim(uint32 handle, uint16 am_addr);

/*************************************************************************************
    
    Function Name :    int radiotestCfgLoLvl(uint32 handle, uint16 lo_lvl);

    Parameters :    handle - handle to the device

                    lo_lvl - analogue LO output level.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This command sets the value of the Analogue Local Oscillator 
                    output level to lvl, over-riding the value calculated by the 
                    internal calibration algorithm.

                    <p>Important Note:
                        Use of this command is unnecessary for all normal users.

*************************************************************************************/
TESTENGINE_API(int) radiotestCfgLoLvl(uint32 handle, uint16 lo_lvl);

/*************************************************************************************
    MISC TESTS
*************************************************************************************/

/*************************************************************************************
    
    Function Name : int radiotestSettle(uint32 handle, uint16 start, uint16 end);

    Parameters :    handle - Handle to the device.

                    start - Channel to start stepping from. 0 to 78.

                    end - Channel to finish stepping at. 0 to 78.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure, 2
                    if not supported over the current connection.

    Description :   Builds the radio's channel LO_TRIM frequency lookup table
                    (LUT), then does a step from the start channel to the
                    end channel, while the synthesiser is running.
                    It digitises the synthesiser (LO_TUNE) error
                    voltage at intervals of 10  20us over the next 200us.
                    <p>The results can be retrieved using hqGetSettle.
                    <p>This function is not supported over a SPI connection.

*************************************************************************************/
TESTENGINE_API(int) radiotestSettle(uint32 handle, uint16 start, uint16 end);

/*************************************************************************************
    
    Function Name : int hqGetSettle(uint32 handle, uint16 * report);

    Parameters :    handle - Handle to the device.

                    report - Pointer to a preallocated 9 element array to
                       receive the results.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :   This function is used to retrieve the results made from a
                    call to radiotestSettle.

*************************************************************************************/
TESTENGINE_API(int) hqGetSettle(uint32 handle, uint16 * r);

/*************************************************************************************
    
    Function Name :    int get_freq_offset(uint32 handle, double * offset, int sample_size);

    Parameters :    handle - handle to the device

                    offset - pointer to the offset. Measured in parts per million (PPM), 
                        this value is an average of sample_size readings from the 
                        BlueCore receiver.
                
                    sample_size - determines how many readings of offset are averaged.
                        The software will only accept values in the range of 20 to 200, 
                        any values outside this range will be forced up to 20 or 200. 
                        The choice of value will determine the accuracy and speed. The 
                        lower the value the quicker but less accurate the results, the 
                        higher the value the more accurate but slower the function. 
                        The optimal value is 60 to 100.

    Returns :        -1 on error, 1 on success, 0 on fail

    Description :    This command will read the offset of a received signal.

*************************************************************************************/
TESTENGINE_API(int) get_freq_offset(uint32 handle, double * offset, int sample_size);

/*************************************************************************************
    PS ACCESS COMMANDS
*************************************************************************************/

/*************************************************************************************
    PS_STORES - the BlueCore persistent store is conceptually a four layer model. When 
    the BlueCore firmware initialises or reads a persistent store value it will always 
    read it from the top most layer where that PS entry is present. When writing or 
    reading to the persistent store in production it is possible to select the PS 
    store layer or let the firmware decide. This selection is carried out by the use of
    the 'stores' parameter of all the PS read and write functions. This parameter is a 
    bit mask so multiple layers can be selected. The layers are defined as follows 
    (bottom to top):

        1. ROM layer - the bottom layer in the model, basically these are the hard 
        coded firmware defaults. This is a read-only layer so all PS writes to this 
        layer will fail. Note that not all PS entries will have a default value so in 
        some cases a PS read will also fail.

        2. Factory-set layer - this layer is not present on BlueCore ROM devices unless
        an external EEPROM is present. PS keys are moved to this layer when 
        "psFactorySet()" is called. This layer can also be written to and read from 
        directly by selecting this layer as the 'stores' parameter.

        3. Implementation - this layer is not present on BlueCore ROM devices unless
        an external EEPROM is present. This layer is where most PS keys are written 
        during production for BlueCore Flash, External and ROM devices with an EEPROM.
        In these cases calling "psFactorySet()" will move the PS values from this 
        layer to the factory-set layer. Calling "psFactoryRestoreAll()" will erase 
        the implemention layer and expose the factory-set layer. When using BlueCore 
        Flash, External and ROM devices with an EEPROM if this layer is selected then
        the function will fail if the flash or EEPROM is read-only, for example if 
        there is a fault on the flash write-enable.

        4. Transient - this layer is the BlueCore RAM. By definition a cold reset or 
        power down reset will clear this layer. A warm reset will retain this layer.
        This layer exists on all BlueCore devices.

    The bitmasks to define these layers are shown below. If no bits are set (0), then
    the firmware will select the layer. If an external storage device is present and 
    functioning correctly then the firmware will write to the implemention layer (this 
    includes BlueCore Flash), otherwise the firmware will write to the transient layer.
**************************************************************************************/
#define    PS_STORES_DEFAULT (0x0000)    /* default */
#define    PS_STORES_I       (0x0001)    /* implementation (normal) */
#define    PS_STORES_F       (0x0002)    /* factory-set */
#define    PS_STORES_R       (0x0004)    /* rom (read-only) */
#define    PS_STORES_T       (0x0008)    /* transient (RAM) */
#define PS_STORES_FR      (0x0006)
#define PS_STORES_IF      (0x0003)
#define PS_STORES_IFR     (0x0007)

/*************************************************************************************
    
    Function Name :    int bccmdSetEeprom(uint32 handle, uint16 log2bytes, uint16 addrMask);

    Parameters :    handle - handle to the device

                    log2bytes - Specifies the size of the EEPROM (log2 bytes). That is 
                        the number of bits required to address any byte of the memory 
                        array.

                    addrMask - A bitmap specifying which, if any, of the slave address 
                        bits are used to specify high-order bits of the array address.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Write the header to the I2C EEPROM to allow the device to be used 
                    to store PS values and VM applications.

*************************************************************************************/
TESTENGINE_API(int) bccmdSetEeprom(uint32 handle, uint16 log2bytes, uint16 addrMask);

/*************************************************************************************
    
    Function Name : int psReadBdAddr( uint32 handle, uint32 * lap, uint8 * uap, uint16 * nap);

    Parameters :    handle - handle to the device
                    
                    lap - pointer to a uint32 to hold the lap portion of the BD_ADDR
                    
                    uap - pointer to a uint8 to hold the uap portion of the BD_ADDR

                    nap - pointer to a uint16 to hold the nap portion of the BD_ADDR

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Function to read the BD_ADDR from the persistent store.

*************************************************************************************/
TESTENGINE_API(int) psReadBdAddr( uint32 handle, uint32 * lap, uint8 * uap, uint16 * nap);

/*************************************************************************************
    
    Function Name :    int psRead( uint32 handle, uint16 ps_key, uint16 store, uint16 arraylen, uint16 * ps, uint16 * len);

    Parameters :    handle - handle to the device

                    ps_key - ps key ID of the value to be read.
                    
                    store - bit mask to identify the PS store layer to write to. See 
                        comments above under PS_STORES.

                    arraylen - size of the array allocated to hold the PS value

                    ps - array of 16-bit words of size "arraylen" to hold the PS value

                    len - Pointer to a 16-bit word

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Used to read the value of the PS key specified

*************************************************************************************/
TESTENGINE_API(int) psRead( uint32 handle, uint16 ps_key, uint16 store, uint16 arraylen, uint16 * ps, uint16 * len);

/*************************************************************************************
    
    Function Name :    int psClear( uint32 handle, uint16 ps_key, uint16 store);

    Parameters :    handle - handle to the device

                    ps_key - ps key value of the entry to be removed

                    store - bit mask to identify the PS store layer(s) from which the PS 
                    entry will be erased.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function removes from the ps the value stored in the  
                    layer specified by the stores parameter. Clearing values from the ps can have 
                    subtle effects. The description of the Layered Model of the ps 
                    stores above shows how clearing a value from the psfl layer can 
                    (re)expose a value in the psf or psrom layer.

*************************************************************************************/
TESTENGINE_API(int) psClear( uint32 handle, uint16 ps_key, uint16 store);

/*************************************************************************************
    
    Function Name :    int psClearAll(uint32 handle, uint16 store);

    Parameters :    handle - handle to the device

                    store - bit mask to identify the PS store layer(s) from which the PS 
                    entries will be erased.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This removes all values from the ps flash; only values in the 
                    psrom layer remain. This command should be used with caution.

*************************************************************************************/
TESTENGINE_API(int) psClearAll(uint32 handle, uint16 store);

/*************************************************************************************
    
    Function Name :    int psFactorySet( uint32 handle);

    Parameters :    handle - handle to the device

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This moves all values in the psfl layer to the psf layer.

*************************************************************************************/
TESTENGINE_API(int) psFactorySet( uint32 handle);

/*************************************************************************************
    
    Function Name :    int psFactoryRestoreAll( uint32 handle);

    Parameters :    handle - handle to the device

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This command removes all values from the psfl store, so restoring 
                    the chips ps to the state it was in when the PS_FACTORY_SET 
                    command was invoked.

*************************************************************************************/
TESTENGINE_API(int) psFactoryRestoreAll( uint32 handle);

/*************************************************************************************
    
    Function Name :    int psFactoryRestore(uint32 handle);

    Parameters :    handle - handle to the device

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This is identical to PS_FACTORY_RESTORE_ALL except that values in 
                    the psfl layer that do not obscure values in the psf and/or psrom 
                    layers are left in place.

*************************************************************************************/
TESTENGINE_API(int) psFactoryRestore(uint32 handle);

/*************************************************************************************
    
    Function Name :    int psSize(uint32 handle, uint16 pskey, uint16 store, uint16 * size);

    Parameters :    handle - handle to the device

                    pskey - PS entry to return the size of.

                    store - PS store to access

                    size - reference to size of PS entry.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    returns the internal amount of data, in uint16's, held by a 
                    particular PS entry. Failure may also denote the the store mask 
                    selected does not contain a valid PS entry.

*************************************************************************************/
TESTENGINE_API(int) psSize(uint32 handle, uint16 pskey, uint16 store, uint16 * size);

/*************************************************************************************
    
    Function Name :    int psWrite( uint32 handle, uint16 ps_key, uint16 store, uint16 ps_length, uint16 *ps);

    Parameters :    handle - handle to the device

                    ps_key - ps key value of the entry to be written

                    store - PS store to access

                    ps_length - length of the data to be written.

                    ps - pointer to an array to hold the key contents

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    writes the PS setting "ps_key" array "ps" of length "ps_length" 
                    to the persistent store layer identified by "store".

*************************************************************************************/
TESTENGINE_API(int) psWrite( uint32 handle, uint16 ps_key, uint16 store, uint16 ps_length, uint16 *ps);

/*************************************************************************************
    
    Function Name :    int psWriteVerify( uint32 handle, uint16 ps_key, uint16 store, uint16 ps_length, uint16 *ps);

    Parameters :    handle - handle to the device

                    ps_key - ps key value of the entry to be written

                    store - PS store to access

                    ps_length - length of the data to be written.

                    ps - pointer to an array to hold the key contents

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    writes the PS setting "ps_key" array "ps" of length "ps_length" 
                    to the persistent store layer PS_STORE_I or PS_STORE_F if one those 
                    values are identified by "store". The function will then perform a 
                    PS read and verify that the PS key has been written correctly.
                    <p>
                    This function will fail if a store mask does not contain PS_STORE_I
                    or PS_STORE_F.

*************************************************************************************/
TESTENGINE_API(int) psWriteVerify(uint32 handle, uint16 ps_key, uint16 store, uint16 ps_length, uint16 *ps);

/*************************************************************************************
    
    Function Name :    int psWriteBdAddr( uint32 handle, uint32 lap, uint32 uap, uint32 nap);

    Parameters :    handle - Handle to the device.

                    lap - LAP portion of the address to write to the persistent
                       store.

                    uap - UAP portion of the address to write to the persistent
                       store.

                    nap - NAP portion of the address to write to the persistent
                       store.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :   This function is used to write the BlueTooth address of the
                    device.

*************************************************************************************/
TESTENGINE_API(int) psWriteBdAddr( uint32 handle, uint32 lap, uint32 uap, uint32 nap);

/*************************************************************************************
    
    Function Name :    int psReadModuleId( uint32 handle, uint32 * module_id);

    Parameters :    handle - handle to the device

                    module_id - pointer to a variable that will hold the returned 
                            module ID.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will attempt to read the module ID stored in 
                    BlueCore. The default for this value is 0 (zero)

*************************************************************************************/
TESTENGINE_API(int) psReadModuleId( uint32 handle, uint32 * module_id);

/*************************************************************************************
    
    Function Name :    int psReadXtalFtrim(uint32 handle, uint16 * ftrim);

    Parameters :    handle - handle to the device

                    ftrim - pointer to a variable that will hold the returned 
                            xtal ftrim.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will attempt to read the xtal ftrim stored in 
                    BlueCore.

*************************************************************************************/
TESTENGINE_API(int) psReadXtalFtrim(uint32 handle, uint16 * ftrim);

/*************************************************************************************
    
    Function Name :    int psWriteXtalFtrim( uint32 handle, uint16 ftrim);

    Parameters :    handle - handle to the device

                    ftrim - Crystal frequency trim

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will write the crystal trim value to the persistent 
                    store.

*************************************************************************************/
TESTENGINE_API(int) psWriteXtalFtrim( uint32 handle, uint16 ftrim);

/*************************************************************************************
    
    Function Name :    int psWriteModuleSecurityCode(uint32 handle, uint16 * code)

    Parameters :    handle - handle to the device

                    code - pointer to 8 member unsigned 16 bit integer array holding 
                    the 128 bit module security code.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will write the module security code to the 
                    persistent store.

*************************************************************************************/
TESTENGINE_API(int) psWriteModuleSecurityCode(uint32 handle, uint16 * code);

/*************************************************************************************
    
    Function Name :    int psWriteModuleId( uint32 handle, uint32 module_id)

    Parameters :    handle - handle to the device

                    module_id - Module ID to be stored in BlueCore persistent store

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will attempt to wriet the module ID to BlueCore. 
                    The default for this value is 0 (zero).

*************************************************************************************/
TESTENGINE_API(int) psWriteModuleId( uint32 handle, uint32 module_id);

/*************************************************************************************
    
    Function Name :    int psWriteBaudrate(uint32 handle, uint16 value)

    Parameters :    handle - handle to the device

                    value - Used determine the baudrate where: 
                        baudrate = value/0.004096

                        <p>Some common values are:
                        <table>
                        <tr><td> 38k4    baud    -   157   (0x009d)
                        <tr><td> 57k6    baud    -   236   (0x00ec)
                        <tr><td> 115k2   baud    -   472   (0x01d8)
                        <tr><td> 230k4   baud    -   944   (0x03b0)
                        <tr><td> 460k8   baud    -   1887  (0x075f)
                        <tr><td> 921k6   baud    -   3775  (0x0ebf)
                        <tr><td> 1382k4  baud    -   5662  (0x161e)
                        </table>
                        The maximum rated speed for the UART hardware is 1.5 Mbaud, although
                        this key can be set to a higher value.


    Returns :        -1 on invalid handle, 1 on success, 0 on failure. 

    Description :    This function will write a value corresponding to the baudrate to 
                    the persistent store. This function can only be used in builds later 
                    than 18.x. For earlier builds the PSKEY_HOSTIO_UART_PS_BLOCK should 
                    be modified.

*************************************************************************************/
TESTENGINE_API(int) psWriteBaudrate(uint32 handle, uint16 value);

/*************************************************************************************
    
    Function Name :    int psWriteRadiotestFirstTrimTime(uint32 handle, uint32 time)

    Parameters :    handle - handle to the device

                    time - The time from the start of a test till the first IQ trim 
                            auto-calibration is done. 

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will write the time to the persistent store.A value 
                    of 0 disables the automatic calibration completely during the 
                    test. A calibration is still done before the test starts. 

*************************************************************************************/
TESTENGINE_API(int) psWriteRadiotestFirstTrimTime(uint32 handle, uint32 time);

/*************************************************************************************
    
    Function Name :    int psReadRadiotestFirstTrimTime(uint32 handle, uint32 * time)

    Parameters :    handle - handle to the device

                    time - The time from the start of a test till the first IQ trim 
                            auto-calibration is done. 

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function will write the time to the persistent store.A value 
                    of 0 disables the automatic calibration completely during the 
                    test. A calibration is still done before the test starts. 

*************************************************************************************/
TESTENGINE_API(int) psReadRadiotestFirstTrimTime(uint32 handle, uint32 * time);

/*************************************************************************************
    
    Function Name :    int psWriteRadiotestLoLvlTrimEnable(uint32 handle, uint16 state)

    Parameters :    handle - handle to the device

                    state - Determine whether IQ trim is enabled. Basically this is a 
                            boolean where 1 = true and 0 = false.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    This function enables trimming of the value for the register 
                    ANA_LO_ENABLE; otherwise, has no effect. This trimming takes place 
                    before the start of each test.  

*************************************************************************************/
TESTENGINE_API(int) psWriteRadiotestLoLvlTrimEnable(uint32 handle, uint16 state);

/*************************************************************************************
    
    Function Name :    int psReadRadiotestLoLvlTrimEnable(uint32 handle, uint16 * state)

    Parameters :    handle - handle to the device

                    state - Determine whether IQ trim is enabled. Basically this is a 
                            boolean where 1 = true and 0 = false.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Reads value of PS setting

*************************************************************************************/
TESTENGINE_API(int) psReadRadiotestLoLvlTrimEnable(uint32 handle, uint16 * state);

/*************************************************************************************
    
    Function Name :    int psWriteRadiotestSubsequentTrimTime(uint32 handle, uint32 time)

    Parameters :    handle - handle to the device

                    time - The time between each IQ trim auto-calibration.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Once the first IQ trim auto calibration is done in test mode, then 
                    subsequent trims are done at regular intervals with the period 
                    being given by this key. If this key is 0 then only the first trim 
                    is done. If PSKEY_RADIOTEST_FIRST_TRIM_TIME is 0 then no trims are 
                    done during the test regardless of the setting of this key. 

*************************************************************************************/
TESTENGINE_API(int) psWriteRadiotestSubsequentTrimTime(uint32 handle, uint32 time);

/*************************************************************************************
    
    Function Name :    int psReadRadiotestSubsequentTrimTime(uint32 handle, uint32 * time)

    Parameters :    handle - handle to the device

                    time - The time between each IQ trim auto-calibration.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Read the PS setting

*************************************************************************************/
TESTENGINE_API(int) psReadRadiotestSubsequentTrimTime(uint32 handle, uint32 * time);

/*************************************************************************************
    
    Function Name :    int psWriteHostInterface(uint32 handle, uint16 transport)

    Parameters :    handle - handle to the device

                    transport - The choice of physical bus. Valid values are:
                    <table>
                    <tr><td> 1 : BCSP 
                    <tr><td> 2 : H2 - USB 
                    <tr><td> 3 : H4 - UART 
                    <tr><td> 4 : Raw UART (VM)
                    </table>

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Select the physical connection that is used to pass information 
                    to and from the host - BCSP, H4, USB, etc. Only one of these can 
                    be used at a time, not least because the USB interface uses some 
                    of the same chip pins as the UART. If this key specifies use of 
                    USB and the chip has no USB hardware support then it reverts to 
                    using BCSP. Much of the chip's support for BCSP is performed by 
                    hardware - this allows interrupt routines to deal with complete 
                    BCSP packets. When the chip uses its UART in a more naive fashion, 
                    e.g., for H4, this support must be disabled. The UART's hardware 
                    support for BCSP must be enabled via PSKEY_UART_CONFIG. The H4 
                    specification requires the use of UART hardware flow control and 
                    no use of parity. These must also be set via PSKEY_UART_CONFIG. 

*************************************************************************************/
TESTENGINE_API(int) psWriteHostInterface(uint32 handle, uint16 transport);

/*************************************************************************************
    
    Function Name :    int psReadHostInterface(uint32 handle, uint16 * transport)

    Parameters :    handle - handle to the device

                    transport - The choice of physical bus. Valid values are:
                    <table>
                    <tr><td> 1 : BCSP 
                    <tr><td> 2 : H2 - USB 
                    <tr><td> 3 : H4 - UART 
                    <tr><td> 4 : Raw UART (VM)
                    </table>

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Reads the Host interface PS setting

*************************************************************************************/
TESTENGINE_API(int) psReadHostInterface(uint32 handle, uint16 * transport);

/*************************************************************************************
    
    Function Name :    int psWriteUsbAttributes(uint32 handle, uint16 bmAttributes);

    Parameters :    handle - handle to the device

                    bmAttributes - The bmAttributes of the Standard Configuration 
                    Descriptor, described in Table 9.8 of USB specification, 
                    version 1.1. 

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Configuration characteristics
                    <table>                        
                    <tr><td> D7: Reserved (set to one)
                    <tr><td> D6: Self-powered
                    <tr><td> D5: Remote Wakeup
                    <tr><td> D4...0: Reserved (reset to zero)
                    </table>
                    D7 is reserved and must be set to one for historical reasons. A 
                    device configuration that uses power from the bus and a local 
                    source reports a non-zero value in MaxPower to indicate the 
                    amount of bus power required and sets D6. The actual power 
                    source at runtime may be determined using the GetStatus(DEVICE) 
                    request (see Section 9.4.5 of USB specification 1.1). If a device 
                    configuration supports remote wakeup, D5 is set to one. 

*************************************************************************************/
TESTENGINE_API(int) psWriteUsbAttributes(uint32 handle, uint16 bmAttributes);

/*************************************************************************************
    
    Function Name :    int psWriteDPlusPullup(uint32 handle, uint16 pio_pin);

    Parameters :    handle - handle to the device

                    pio_pin - The PIO line used to control the pull-up resistor on the 
                    USB D+ line. 

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    The absence of this key in the ps indicates that this feature is 
                    not in use. This value is only used if the chip is presenting its 
                    USB interface. See the description of PSKEY_HOST_INTERFACE.

*************************************************************************************/
TESTENGINE_API(int) psWriteDPlusPullup(uint32 handle, uint16 pio_pin);

/*************************************************************************************
    
    Function Name :    int psWriteUsbMaxPower(uint32 handle, uint16 max_power);

    Parameters :    handle - handle to the device

                    pio_pin - The MaxPower field of the local USB device, as defined 
                    in Table 9.8 of version 1.1 of the USB specification. Bizarrely, 
                    this value is given in units of 2mA. 

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Function to write the pskey PSKEY_USB_MAX_POWER  to the persistent
                    store. This value is only used if the chip is presenting its USB 
                    interface. See the description of PSKEY_HOST_INTERFACE.

*************************************************************************************/
TESTENGINE_API(int) psWriteUsbMaxPower(uint32 handle, uint16 max_power);

/*************************************************************************************
    
    Function Name :    int psWritePioProtectMask(uint32 handle, uint16 mask);

    Parameters :    handle - handle to the device

                    mask - PIO mask to protect PIO lines from unwanted access. If a 
                    bit of the pskey's value is set high then application code cannot 
                    change the value of the corresponding PIO port pin. 

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    The chip's PIO port can function as a general purpose input and 
                    output port. However, various optional hardware and software 
                    configurations require some PIO pins for their own needs, e.g., an 
                    optional external PA/LNA block is driven using PIO pins 0 and 1. 
                    This pskey prevents applications changing PIO pins that are 
                    required for lower level functions. This blocking action applies 
                    to host-based applications requesting PIO changes via BCCMD and to 
                    VM applications running on the chip. Bits 0 to 7 of this uint16 
                    pskey map to PIO0 to PIO7 respectively. If a bit of the pskey's 
                    value is set high then application code cannot change the value of 
                    the corresponding PIO port pin. The default value, 0x03, suits 
                    Casira as this has an external PA/LNA. 

*************************************************************************************/
TESTENGINE_API(int) psWritePioProtectMask(uint32 handle, uint16 mask);

/*************************************************************************************
    
    Function Name :    int psReadPioProtectMask(uint32 handle, uint16 * mask);

    Parameters :    handle - handle to the device

                    mask - PIO mask to protect PIO lines from unwanted access. If a 
                    bit of the pskey's value is set high then application code cannot 
                    change the value of the corresponding PIO port pin. 

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Reads the PIO protect mask PS setting

*************************************************************************************/
TESTENGINE_API(int) psReadPioProtectMask(uint32 handle, uint16 * mask);

/*************************************************************************************
    
    Function Name :    int psWriteTxOffsetHalfMhz(uint32 handle, int16 offset);

    Parameters :    handle - handle to the device

                    offset - transmit offset in units of 500kHz. For example -2 == -1MHz

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Sets the transmit offset.

*************************************************************************************/
TESTENGINE_API(int) psWriteTxOffsetHalfMhz(uint32 handle, int16 offset);

/*************************************************************************************
    
    Function Name :    int psReadTxOffsetHalfMhz(uint32 handle, int16 * offset);

    Parameters :    handle - handle to the device

                    offset - transmit offset in units of 500kHz. For example -2 == -1MHz

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    reads the transmit offset.

*************************************************************************************/
TESTENGINE_API(int) psReadTxOffsetHalfMhz(uint32 handle, int16 * offset);

/*************************************************************************************
    
    Function Name :    int psWriteUsrValue(uint32 handle, uint16 user_no, uint16 length, uint16 * entry);

    Parameters :    handle - handle to the device

                    user_no - Value between 0 and 49 which refers to 'n' in PSKEY_USRn

                    length - length of PS key value in uint16's

                    entry - pointer to an array containing the data to be written to 
                    the PS.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Writes to PSKEY_USRn.

*************************************************************************************/
TESTENGINE_API(int) psWriteUsrValue(uint32 handle, uint16 user_no, uint16 length, uint16 * entry);

/*************************************************************************************
    
    Function Name :    int psReadUsrValue(uint32 handle, uint32 user_no, uint16 maxLen, uint16 * length, uint16 * entry);

    Parameters :    handle - handle to the device

                    user_no - Value between 0 and 49 which refers to 'n' in PSKEY_USRn

                    maxLen - length of the array to hold the returned value

                    length - pointer to the length of the returned ps entry

                    entry - pointer to an array to hold the returned PS value

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Reads the PSKEY_USRn.

*************************************************************************************/
TESTENGINE_API(int) psReadUsrValue(uint32 handle, uint32 user_no, uint16 maxLen, uint16 * length, uint16 * entry);

/*************************************************************************************
    
    Function Name :    int psWritePowerTable(uint32 handle, int num_entries, uint8 * intPA, uint8 * extPA, int * power);

    Parameters :    handle - handle to the device

                    num_entries - Number of entries in the power table

                    intPA - pointer to an array of unsigned char of size num_entries 
                            containing the intPA entries for the power table. 
                    
                    extPA - pointer to an array of unsigned char of size num_entries 
                            containing the extPA entries for the power table.
 
                    power - pointer to an array of signed integers of size num_entries 
                            containing the Output power entries, in dBm, for the power 
                    table. 
                    
    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Writes to PSKEY_LC_POWER_TABLE

*************************************************************************************/
TESTENGINE_API(int) psWritePowerTable(uint32 handle, uint16 num_entries, uint8 * intPA, uint8 * extPA, int * power);

/*************************************************************************************
    
    Function Name :    int psReadPowerTable(uint32 handle,  int maxSize, int * num_entries, uint8 * intPA, uint8 * extPA, int * power);

    Parameters :    handle - handle to the device

                    maxSize - size of the arrays to hold the intPA, extPA and power

                    num_entries - pointer to the number of entries in the power table

                    intPA - pointer to an array of unsigned char of size num_entries 
                            containing the intPA entries for the power table. 
                    
                    extPA - pointer to an array of unsigned char of size num_entries 
                            containing the extPA entries for the power table.
 
                    power - pointer to an array of signed integers of size num_entries 
                            containing the Output power entries, in dBm, for the power 
                    table. 
                    
    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Reads the PSKEY_LC_POWER_TABLE

*************************************************************************************/
TESTENGINE_API(int) psReadPowerTable(uint32 handle,  int maxSize, int * num_entries, uint8 * intPA, uint8 * extPA, int * power);

/*************************************************************************************
    
    Function Name :    int psWriteVmDisable(uint32 handle, uint8 vmDisable);

    Parameters :    handle - handle to the device

                    vmDisable - Boolean value where non-zero indicates that the VM 
                    will be disabled after the next reset.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Writes to PSKEY_VM_DISABLE

*************************************************************************************/
TESTENGINE_API(int) psWriteVmDisable(uint32 handle, uint8 vmDisable);

/*************************************************************************************
    
    Function Name :    int psReadVmDisable(uint32 handle, uint8 * vmDisable);

    Parameters :    handle - handle to the device

                    vmDisable - Boolean value where non-zero indicates that the VM 
                    is disabled. 

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Writes to PSKEY_VM_DISABLE

*************************************************************************************/
TESTENGINE_API(int) psReadVmDisable(uint32 handle, uint8 * vmDisable);

/*************************************************************************************
    HCI FUNCTION SET
*************************************************************************************/

/*************************************************************************************
    
    Function Name :    int hciSlave(uint32 handle);

    Parameters :    handle - handle to the device

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Performs four steps:
                    1. Sets the event filter to auto accept a connection request. 
                    Implements the command HCI_Set_Event_Filter with the following
                    parameters:
                    <table>
                    <tr><td> 0x02 - Connection  setup filter type
                    <tr><td> 0x00 - Allow connections from all devices
                    <tr><td> 0x02 - Auto accept the connection
                    </table>
                    
                    2. Implements the command HCI_WriteScan_Enable with the following
                    parameter:
                        0x03 - Inquiry scan enabled, Page scan enabled.

*************************************************************************************/
TESTENGINE_API(int) hciSlave(uint32 handle);

/*************************************************************************************
    
    Function Name :    int hciSetEventFilterAutoacceptConnection(uint32 handle);

    Parameters :    handle - handle to the device


    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Sets the event filter to auto accept a connection request. 
                    Implements the command HCI_Set_Event_Filter with the following
                    parameters:
                    <table>
                    <tr><td> 0x02 - Connection  setup filter type
                    <tr><td> 0x00 - Allow connections from all devices
                    <tr><td> 0x02 - Auto accept the connection
                    </table>

*************************************************************************************/
TESTENGINE_API(int) hciSetEventFilterAutoacceptConnection(uint32 handle);

/*************************************************************************************
    
    Function Name :    int hciWriteInquiryScanActivity(uint32 handle, uint16 inquiryscan_interval, uint16 inquiryscan_window);

    Parameters :    handle - handle to the device

                    inquiryscan_interval - defines the amount of time between consecutive 
                        inquiry scans.

                    inquiryscan_window - defines the amount of time for the duration of 
                        the inquiry scan.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure 

    Description :    Implements the command HCI_Write_Inquiryscan_activity.

*************************************************************************************/
TESTENGINE_API(int) hciWriteInquiryScanActivity(uint32 handle, uint16 inquiryscan_interval, uint16 inquiryscan_window);

/*************************************************************************************
    
    Function Name :    int hciWritePageScanActivity(uint32 handle, uint16 pagescan_interval, uint16 pagescan_window);

    Parameters :    handle - handle to the device

                    pagescan_interval - defines the amount of time between consecutive 
                        page scans.

                    pagescan_window - defines the amount of time for the duration of 
                        the page scan.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Implements the command HCI_Write_Pagescan_activity.

*************************************************************************************/
TESTENGINE_API(int) hciWritePageScanActivity(uint32 handle, uint16 pagescan_interval, uint16 pagescan_window);

/*************************************************************************************
    
    Function Name :    int hciWriteScanEnable(uint32 handle, uint8 scan_enable);

    Parameters :    handle - handle to the device

                    scan_enable - controls whether or not the Bluetooth device will 
                        periodically scan for page attempts and/or inquiry requests 
                        from other Bluetooth devices.
                        <table>
                        <tr><td> 0x00 = No Scans enabled.
                        <tr><td> 0x01 = Inquiry Scan enabled. Page Scan disabled.
                        <tr><td> 0x02 = Inquiry Scan disabled. Page Scan enabled.
                        <tr><td> 0x03 = Inquiry Scan enabled. Page Scan enabled.
                        </table>

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Implements the command HCI_WriteScan_Enable.

*************************************************************************************/
TESTENGINE_API(int) hciWriteScanEnable(uint32 handle, uint8 scan_enable);

/*************************************************************************************
    
    Function Name :    int hciInquiry(uint32 handle, uint8 inquiryLength, uint8 numResponses, uint32 lap);

    Parameters :    handle - handle to the device

                    inquiryLength - Maximum amount of time before the inquiry is 
                    halted, as defined by the BT spec.

                    numResponses - Maximum number of responses before inquiry is 
                    halted, as defined in the BT spec. 0x00 is unlimited.

                    lap - The LAP from which the inquiry access code is derived, as 
                    defined in the BT spec.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Causes the device to enter inquiry mode. 
                    This function will NOT wait for any inquiry results.

*************************************************************************************/
TESTENGINE_API(int) hciInquiry(uint32 handle, uint8 inquiryLength, uint8 numResponses, uint32 lap);

/*************************************************************************************
    
    Function Name :    int hciGetInquiryResults(uint32 handle, uint32 * lap, uint8 * uap, uint16 * nap, int maxLen, int * len);

    Parameters :    handle - handle to the device

                    lap - pointer to the array of lap's as defined by the returned value.

                    uap - pointer to the array of uap's as defined by the returned value.

                    nap - pointer to the array of nap's as defined by the returned value.

                    maxLen - size of the arrays allocated for the lap, uap and nap.

                    len - pointer to a variable to hold the actual data returned with 
                        the lap, uap and nap.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Retrieves the bd_addrs of the devices found during the last 
                    completed inquiry. If an inquiry is in progress then this function 
                    will wait for a time based on the inquiryLength parameter passed 
                    to do_inquiry().

*************************************************************************************/
TESTENGINE_API(int) hciGetInquiryResults(uint32 handle, uint32 * lap, uint8 * uap, uint16 * nap, int maxLen, int * len);

/*************************************************************************************
    
    Function Name :    int hciInquiryCancel(uint32 handle);

    Parameters :    handle - handle to the device

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Causes the device to exit inquiry mode. The DLL will check if the 
                    device is currently in inquiry before issuing this.Failure on 
                    invalid handle or DM commands enabled.

*************************************************************************************/
TESTENGINE_API(int) hciInquiryCancel(uint32 handle);

/*************************************************************************************
    
    Function Name :    int hciCreateConnection(uint32 handle, uint32 lap, uint8 uap, uint16 nap, uint16 pkt_type, uint16 * connectionHandle);

    Parameters :    handle - handle to the device

                    lap - lap of bd_addr. Must be one of the bd_addrs returned by get_inquiry_results.

                    uap - uap of bd_addr. Must be one of the bd_addr's returned by 
                        get_inquiry_results.

                    nap - nap of bd_addr. Must be one of the bd_addr's returned by 
                        get_inquiry_results.

                    pkt_type - Or-ed combination of packet types as defined in the 
                        Bluetooth specification.
                        <table>
                        <tr><td> HCI_PKT_DM1 ((uint16)0x0008) SCO and ACL
                        <tr><td> HCI_PKT_DH1 ((uint16)0x0010) ACL only
                        <tr><td> HCI_PKT_DM3 ((uint16)0x0400) ACL only
                        <tr><td> HCI_PKT_DH3 ((uint16)0x0800) ACL only
                        <tr><td> HCI_PKT_DM5 ((uint16)0x4000) ACL only
                        <tr><td> HCI_PKT_DH5 ((uint16)0x8000) ACL only
                        </table>
                        BlueChat default is:
                        (HCI_PKT_DH1|HCI_PKT_DH3|HCI_PKT_DH5|HCI_PKT_DM1|HCI_PKT_DM3|HCI_PKT_DM5)

                    connectionHandle - connection handle to a Bluetooth connection. 
                        NOTE: The connection handle is local to a device and not a link. 
                        Therefore when you create a connection each member could have a 
                        different connection handle for that link so the value returned by 
                        this function should    only be used be this device.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure
                    

    Description :    Causes the device to attempt to create a connection with a device 
                    discovered during the inquiry phase. This function will wait for a 
                    connection complete event with a 3 second time out. Success is 
                    determined by:
                    <ol>
                    <li> Valid handle
                    <li> Successful connection complete event
                    <li> Invalid BD_ADDR (not part of the inquiry results list).
                    </ol>

*************************************************************************************/
TESTENGINE_API(int) hciCreateConnection(uint32 handle, uint32 lap, uint8 uap, uint16 nap, uint16 pkt_type, uint16 * connectionHandle);

/*************************************************************************************
    
    Function Name :    int hciCreateConnectionNoInquiry(uint32 handle, uint32 lap, uint8 uap, uint16 nap, uint16 pkt_type, uint8 page_scan_rep_mode, uint8 page_scan_mode, uint16 clock_offset, uint8 allow_role_switch, uint16 * connectionHandle)

    Parameters :    handle - handle to the device

                    lap - lap of bd_addr.

                    uap - uap of bd_addr.

                    nap - nap of bd_addr.

                    pkt_type - as do_create_connection(...)

                    page_scan_repetition_mode - page scan repetition mode supported by
                        the slave device. (0 = R0, 1 = R1, 2 = R2)

                    page_scan_mode - BT Spec. requires this to be set to 0.

                    clock_offset - The clock offset between the devices. See the BT
                                   Spec "Create Connection Command" for possible values.

                    allow_role_switch - Specifies if the local device accepts the request
                                        of a master/slave role switch. 0 to not allow, 1 to allow

                    connectionHandle - connection handle to a Bluetooth connection. 
                        NOTE: The connection handle is local to a device and not a link. 
                        Therefore when you create a connection each member could have a 
                        different connection handle for that link so the value returned by 
                        this function should    only be used be this device.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Causes the device to attempt to create a connection with a remote 
                    device. This function will wait for a connection complete event 
                    with a 5 second time out. Success is 
                    determined by:
                    <ol>
                    <li> Valid handle
                    <li> Successful connection complete event
                    <li> Invalid BD_ADDR (not part of the inquiry results list).
                    </ol>

*************************************************************************************/
TESTENGINE_API(int) hciCreateConnectionNoInquiry(uint32 handle, uint32 lap, uint8 uap, uint16 nap, uint16 pkt_type, uint8 page_scan_rep_mode, uint8 page_scan_mode, uint16 clock_offset, uint8 allow_role_switch, uint16 * connectionHandle);

/*************************************************************************************
    
    Function Name :    int hciCreateScoConnection(uint32 handle, uint16 aclConnectionHandle, uint16 pkt_type, uint16 * scoConnectionHandle);

    Parameters :    handle - handle to the device

                    aclConnectionHandle - ACL connection handle.

                    pkt_type - Or-ed combination of packet types as defined in the 
                        Bluetooth specification.
                        <table>
                        <tr><td> HCI_PKT_HV1 ((uint16)0x0020)
                        <tr><td> HCI_PKT_HV2 ((uint16)0x0040)
                        <tr><td> HCI_PKT_HV3 ((uint16)0x0080)
                        </table>

                    scoConnectionHandle - pointer to a variable to hold the returned SCO 
                        connection handle.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure 

    Description :    This command will cause the link manager to create a SCO connection 
                    using the ACL connection specified by the Connection_Handle 
                    command parameter. Success is determined by:
                    <ol>
                    <li> Valid handle
                    <li> Successful connection complete event
                    </ol>

*************************************************************************************/
TESTENGINE_API(int) hciCreateScoConnection(uint32 handle, uint16 aclConnectionHandle, uint16 pkt_type, uint16 * scoConnectionHandle);

/*************************************************************************************
    
    Function Name :    int hciWriteLinkPolicySettings(uint32 handle, uint16 connection_handle, uint16 link_policy_settings);

    Parameters :    handle - handle to the device

                    connection_handle - Bluetooth connection handle to remote device.

                    link_policy_settings - determines the behavior of the local Link 
                        Manager when it receives a request from a remote device or it 
                        determines itself to change the master-slave role or to enter 
                        the hold, sniff, or park mode.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Causes the device to attempt to write the link policy settings.
                    Success determined by:
                    <ol>
                    <li> Valid handle
                    <li> Valid connection handle
                    </ol>

*************************************************************************************/
TESTENGINE_API(int) hciWriteLinkPolicySettings(uint32 handle, uint16 connection_handle, uint16 link_policy_settings);

/*************************************************************************************
    
    Function Name :    int hciSendAclFile(uint32 handle, uint16 connHandle, const char* fileName)

    Parameters :    
                  handle - Handle to the device that will send the contents of
                      the given file.

                  connHandle - ACL connection handle as returned by
                      hciCreateConnection or hciCreateConnectionNoInquiry.

                  fileName - Name of the file whose contents will be transmitted
                      as ACL packets.

    Returns :     -1 on invalid handle, 1 on success, 0 on failure

    Description : This function is used to transmit the contents of a file as
                  ACL data to another device. Before this function is called a
                  valid ACL connection must have be established with a call to
                  either hciCreateConnection or hciCreateConnectionNoInquiry.
                  <p>Before transmitting data a call to hciResetAclState must be
                  made on the receiving device.
                  <p>When a file is sent the receiving device must be polled using
                  the hciGetAclState function for a result of ACL_RECEIVED (3)
                  at which point the entire file should have been received.
                  <p>The received file will be saved in the applications run
                  directory regardless of where it was transmitted from. The
                  received file name may be different to the original. The 
                  hciGetAclFileName function should be used to find the name
                  that the received data was saved to.

*************************************************************************************/
TESTENGINE_API(int) hciSendAclFile(uint32 handle, uint16 connHandle, const char* fileName);

/*******************************************************************************
    
 Function Name : int hciSendAclData(uint32 aHandle, uint16 aConnHandle, const uint8* aData, const uint16 aLength)

 Parameters :    
                 aHandle - Handle to the device that will send the contents of
                     the given file.

                 aConnHandle - ACL connection handle as returned by
                     hciCreateConnection or hciCreateConnectionNoInquiry.

                 aData - Pointer to array of bytes to be transmitted.

                 aLength - Length of the array (in bytes) pointed to by aData.
                     Maximum length is 65535.

 Returns :       -1 on invalid handle, 1 on success, 0 on failure

 Description : This function is used to transmit an array of bytes as
               ACL data to another device. Before this function is called a
               valid ACL connection must have been established with a call to
               either hciCreateConnection or hciCreateConnectionNoInquiry.
               <p>Before transmitting data a call to hciResetAclState must be
               made on the receiving device.
               <p>When data is sent the receiving device must be polled using
               the hciGetAclState function for a result of ACL_RECEIVED (3)
               at which point all data should have been received.
               <p>The received data can be read using the hciGetAclData
               function.
               
*******************************************************************************/
TESTENGINE_API(int) hciSendAclData(uint32 aHandle, uint16 aConnHandle, const uint8* aData, const uint32 aLength);

/*******************************************************************************

  Function Name : int hciGetAclData(uint32 aHandle, uint8* aData)

  Parameters :    aHandle - Handle to the device that received ACL data.

                  aData - Pointer to a pre-allocated byte array to receive
                     ACL data packet. If set to 0 no data will be copied.

  Returns :       Number of bytes in packet.

  Description :   This function can be used to retrieve the contents of a
                  received ACL packet.

*******************************************************************************/
TESTENGINE_API(uint32) hciGetAclData(uint32 aHandle, uint8* aData);

/*************************************************************************************
    
    Function Name :    int hciGetAclFileName(uint32 handle, char * aFileName)

    Parameters :    
                  handle - A valid handle to the device.

                  aFileName - A pre-allocated string to receive the name
                      of the file. This parameter can be set to 0, in which
                      case the function will just return the number of
                      characters (NOT including a null terminator) required
                      to hold the file name.

    Returns :      The length of the file name string if successful, otherwise
                  0 on error.

    Description : The file name of received ACL data is not
                  necessarily the same as the one transmitted, because of one
                  of the following reasons:
                  <ol>
                   <li> File already exists
                   <li> File was not in the applications run folder
                  </ol>
                  This function is therefore used to find the name of the file
                  containing received ACL data. The name is returned in the 
                  aFileName argument which should be a pointer to a 
                  preallocated character
                  string large enough to accept the file name. The required 
                  string size can be found by calling this function with the
                  aFileName argument set to 0.

*************************************************************************************/
TESTENGINE_API(int) hciGetAclFileName(uint32 handle, char * aFileName);

/*************************************************************************************
    
    Function Name :    int hciGetAclState(uint32 handle)

    Parameters :    
                  handle - A valid handle to the device.

    Returns :      The state of an ACL transmission. This can be one of the
                  following values:
                  <table>
                  <tr><td> ACL_IDLE<td>0<td>No transfer taking place.
                  <tr><td> ACL_FILENAME<td>1<td>Receiving file name packet.
                  <tr><td> ACL_RECEIVING<td>2<td>Receiving data packets.
                  <tr><td> ACL_RECEIVED<td>3<td>File received.
                  <tr><td> ACL_ERROR<td>4<td>Error occured.
                  </table>

    Description : This function is used to check the state of a trasmission in
                  progress. It should be called for the device that is 
                  RECEIVING data.

*************************************************************************************/
TESTENGINE_API(int) hciGetAclState(uint32 handle);

/*************************************************************************************
    
    Function Name :    int hciResetAclState(uint32 handle)

    Parameters :    
                  handle - A valid handle to the device.

    Returns :      -1 on invalid handle, 1 on success, 2 if HCI is not
                  supported by firmware or 0 on any other error.

    Description : This function should be called by the RECEIVING device before
                  a call to hclSendAclData.

*************************************************************************************/
TESTENGINE_API(int) hciResetAclState(uint32 handle);

/*************************************************************************************
    
    Function Name :    int bccmdGetAnaXtalFtrim(uint32 handle, uint16 * ftrim)

    Parameters :    
                  handle - A valid handle to the device.

                  ftrim - Variable to receive value of ftrim.

    Returns :     -1 on invalid handle, 1 on success, 2 if BCCMD is not supported by
                  firmware or 0 on any other error.

    Description :  This function is used to retrieve the BlueCore crystal trim value.
                   It can be used to get the crystal trim value on devices where the
                   firmware does not have radiotest functionality.
                   It can only be used on firmware that supports BCCMD_ANA_FTRIM_READWRITE.
                   

*************************************************************************************/
TESTENGINE_API(int) bccmdGetAnaXtalFtrim(uint32 handle, uint16 * ftrim);

/*************************************************************************************
    
    Function Name :    int bccmdSetAnaXtalFtrim(uint32 handle, uint16 ftrim)

    Parameters :    
                  handle - A valid handle to the device.

                  ftrim - Variable to receive value of ftrim.

    Returns :     -1 on invalid handle, 1 on success, 2 if BCCMD is not supported by
                  firmware or 0 on any other error.

    Description : This function is used to set the BlueCore crystal trim value.
                  It is equivalent to radiotestCfgXtalFtrim but can be used to set
                  the trim value on devices where the firmware does not have radiotest functionality.
                  It can only be used on firmware that supports BCCMD_ANA_FTRIM_READWRITE.

*************************************************************************************/
TESTENGINE_API(int) bccmdSetAnaXtalFtrim(uint32 handle, uint16 ftrim);

/*************************************************************************************
    
    Function Name :    int hciSniffMode(uint32 handle, uint16 connection_handle, uint16 sniff_max_interval, uint16 sniff_min_interval, uint16 sniff_attempt, uint16 sniff_timeout);

    Parameters :    handle - handle to the device

                    connection_handle - Bluetooth connection handle to remote device.

                    sniff_max_interval - Maximum acceptable number of Baseband slots 
                        between each sniff period.

                    sniff_min_interval - Minimum acceptable number of Baseband slots 
                        between each sniff period.

                    sniff_attempt - Number of Baseband receive slots for sniff attempt.

                    sniff_timeout - Number of Baseband receive slots for sniff timeout.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Causes the device to attempt to enter Sniff Mode with a remote device.
                    Success determined by:
                    <ol>
                    <li> Valid handle
                    <li> Valid connection handle
                    </ol>

*************************************************************************************/
TESTENGINE_API(int) hciSniffMode(uint32 handle, uint16 connection_handle, uint16 sniff_max_interval, uint16 sniff_min_interval, uint16 sniff_attempt, uint16 sniff_timeout);

/*************************************************************************************
    
    Function Name :    int hciExitSniff(uint32 handle, uint16 connection_handle);

    Parameters :    handle - handle to the device

                    connection_handle - Bluetooth connection handle to remote device.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Causes the device to attempt to exit Sniff Mode with a remote device.
                    Success determined by:
                    <ol>
                    <li> Valid handle
                    <li> Valid connection handle
                    <li> DM commands not in use
                    </ol>

*************************************************************************************/
TESTENGINE_API(int) hciExitSniff(uint32 handle, uint16 connection_handle);

/*************************************************************************************
    
    Function Name :    int hciDisconnect(uint32 handle, uint16 connection_handle);

    Parameters :    handle - handle to the device

                    connection_handle - Bluetooth connection handle to remote device.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Causes the device to request a disconnect from a remote Bluetooth. 
                    The DLL will wait, with a 5 second timeout, for the disconnect 
                    event to be returned. The memory for all disconnected devices will 
                    be freed for this handle. If the remote device is also connected 
                    via TestEngine it is important to run hciPollDisconnectComplete(..) 
                    to confirm the correct operation and to free any memory on that 
                    handle.
                    Success is determined by:
                    <ol>
                    <li> Valid handle
                    <li> Valid active connection_handle
                    <li> Successful completion of disconnect.
                    </ol>

*************************************************************************************/
TESTENGINE_API(int) hciDisconnect(uint32 handle, uint16 connection_handle);

/*************************************************************************************
    
    Function Name :    int hciGetConnectionHandle(uint32 handle, uint32 lap, uint8 uap, uint16 nap, uint16 * connectionHandle);


    Parameters :    handle - handle to the device

                    lap - lap of bd_addr. 

                    uap - uap of bd_addr. 

                    nap - nap of bd_addr. 

                    connectionHandle - pointer to a variable which will hold the returned 
                        connection handle.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Returns the connection handle, if existing, between the device 
                    identified by the "handle" parameter and the device identified by 
                    the Bluetooth address. Failure on invalid handle and DM commands 
                    enabled

*************************************************************************************/
TESTENGINE_API(int) hciGetConnectionHandle(uint32 handle, uint32 lap, uint8 uap, uint16 nap, uint16 * connectionHandle);

/*************************************************************************************
    
    Function Name :    int hciConnectionStatus(uint32 handle, uint16 connection_handle);


    Parameters :    handle - handle to the device

                    connection_handle - Bluetooth connection handle to remote device.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Checks whether the connection handle points to a valid, active 
                    Bluetooth connection.Failure on invalid handle and DM commands 
                    enabled.

*************************************************************************************/
TESTENGINE_API(int) hciConnectionStatus(uint32 handle, uint16 connection_handle);

/*************************************************************************************
    
    Function Name :    int hciEnableDeviceUnderTestMode(uint32 handle);

    Parameters :    handle - handle to the device

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Causes the device to send the enable device under test mode.
                    Success is determined by:
                    <ol>
                    <li> Valid handle
                    <li> Command complete within timeout
                    </ol>

*************************************************************************************/
TESTENGINE_API(int) hciEnableDeviceUnderTestMode(uint32 handle);

/*************************************************************************************
    
    Function Name :    int hciGetLinkQuality(uint32 handle, uint16 connection_handle, uint8 * quality);

    Parameters :    handle - handle to the device

                    connection_handle - Bluetooth connection handle to remote device.

                    quality - pointer to the link quality parameter returned by this function.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Reads the link quality

*************************************************************************************/
TESTENGINE_API(int) hciGetLinkQuality(uint32 handle, uint16 connection_handle, uint8 * quality);

/*************************************************************************************
    
    Function Name :    int hciReadRemoteVersionInformation(uint32 handle, uint16 connection_handle, uint32 * r);

    Parameters :    handle - handle to the device

                    connection_handle - Bluetooth connection handle to remote device.

                    r - a 4 member array of unsigned 32 bit integers. On success r is:
                    <table>
                    <tr><td> r[0] = connection_handle
                    <tr><td> r[1] = lmp_version, as defined by the Bluetooth spec.
                    <tr><td> r[2] = Manufacturer name.
                    <tr><td> r[3] = lmp_subversion
                    </table>
                    With BlueCore the lmp_subversion is the firmware build ID.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Reads the remoted version information.

*************************************************************************************/
TESTENGINE_API(int) hciReadRemoteVersionInformation(uint32 handle, uint16 connection_handle, uint32 * r);

/*************************************************************************************
    
    Function Name :    int hciReadRemoteNameRequest(uint32 handle, uint32 lap, uint8 uap, uint16 nap, uint8 page_scan_repetition_mode, uint8 page_scan_offset, uint16 clock_offset, char * r);

    Parameters :    handle - handle to the device

                    lap - lap of bd_addr. 

                    uap - uap of bd_addr. 

                    nap - nap of bd_addr. 
                    
                    page_scan_repetition_mode - page scan mode supported by the remote 
                        device.

                    page_scan_offset - page scan mode supported by the remote 
                        device.

                    clock_offset - The clock offset between the devices.

                    r - pointer to the remote name returned by the command. This needs
                        to be preallocated to at least 249 bytes.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Reads the remoted name.

*************************************************************************************/
TESTENGINE_API(int) hciReadRemoteNameRequest(uint32 handle, uint32 lap, uint8 uap, uint16 nap, uint8 page_scan_repetition_mode, uint8 page_scan_offset, uint16 clock_offset, char * r);

/*************************************************************************************
    DM ONLY COMMAND SET
*************************************************************************************/

/*************************************************************************************
    
    Function Name :    int dmRegisterReq(uint32 handle);

    Parameters :    handle - handle to the device

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Causes the device to register the application manager queue  
                    command. No other DM commands will function unless this is called.
                    Success is determined by:
                    <ol>
                    <li> Valid handle
                    <li> Command complete within timeout
                    <li> non-HCI firmware
                    </ol>

*************************************************************************************/
TESTENGINE_API(int) dmRegisterReq(uint32 handle);

/*************************************************************************************
    
    Function Name :    int dmSlave(uint32 handle);

    Parameters :    handle - handle to the device

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Performs two steps:
                    <ol>
                    <li>Sets the event filter to auto accept a connection request. 
                    Implements the command DM_HCI_Set_Event_Filter with the following
                    parameters:
                    <table>
                    <tr><td> 0x02 - Connection  setup filter type
                    <tr><td> 0x00 - Allow connections from all devices
                    <tr><td> 0x02 - Auto accept the connection
                    </table>
                    
                    <li>Implements the command DM_HCI_WriteScan_Enable with the following
                    parameter:
                        <p>0x03 - Inquiry scan enabled, Page scan enabled.
                    </ol>

*************************************************************************************/
TESTENGINE_API(int) dmSlave(uint32 handle);

/*************************************************************************************
    
    Function Name :    int dmEnableDeviceUnderTestMode(uint32 handle);

    Parameters :    handle - handle to the device

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Causes the device to send the enable device under test mode.
                    Success is determined by:
                    <ol>
                    <li> Valid handle
                    <li> Command complete within timeout
                    </ol>

*************************************************************************************/
TESTENGINE_API(int) dmEnableDeviceUnderTestMode(uint32 handle);

/*************************************************************************************
    
    Function Name :    int dmWritePageScanActivity(uint32 handle, uint16 pagescan_interval, uint16 pagescan_window);

    Parameters :    handle - handle to the device

                    pagescan_interval - defines the amount of time between consecutive 
                        page scans.

                    pagescan_window - defines the amount of time for the duration of 
                        the page scan.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Implements the command DM_HCI_Write_Pagescan_activity.

*************************************************************************************/
TESTENGINE_API(int) dmWritePageScanActivity(uint32 handle, uint16 pagescan_interval, uint16 pagescan_window);

/*************************************************************************************
    
    Function Name :    int dmWriteInquiryScanActivity(uint32 handle, uint16 inquiryscan_interval, uint16 inquiryscan_window);

    Parameters :    handle - handle to the device

                    inquiryscan_interval - defines the amount of time between consecutive 
                        inquiry scans.

                    inquiryscan_window - defines the amount of time for the duration of 
                        the inquiry scan.

    Returns :        -1 on invalid handle, 1 on success, 0 on failure 

    Description :    Implements the command DM_HCI_Write_Inquiryscan_activity.

*************************************************************************************/
TESTENGINE_API(int) dmWriteInquiryScanActivity(uint32 handle, uint16 inquiryscan_interval, uint16 inquiryscan_window);

/*************************************************************************************
    
    Function Name :    int dmWriteScanEnable(uint32 handle, uint8 scan_enable);

    Parameters :    handle - handle to the device

                    scan_enable - controls whether or not the Bluetooth device will 
                        periodically scan for page attempts and/or inquiry requests 
                        from other Bluetooth devices.
                        <table>
                        <tr><td> 0x00 = No Scans enabled.
                        <tr><td> 0x01 = Inquiry Scan enabled. Page Scan disabled.
                        <tr><td> 0x02 = Inquiry Scan disabled. Page Scan enabled.
                        <tr><td> 0x03 = Inquiry Scan enabled. Page Scan enabled.
                        </table>

    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Implements the command DM_HCI_WriteScan_Enable.

*************************************************************************************/
TESTENGINE_API(int) dmWriteScanEnable(uint32 handle, uint8 scan_enable);

/*************************************************************************************
    
    Function Name :    int dmSetEventFilterAutoacceptConnection(uint32 handle);

    Parameters :    handle - handle to the device


    Returns :        -1 on invalid handle, 1 on success, 0 on failure

    Description :    Sets the event filter to auto accept a connection request. 
                    Implements the command DM_HCI_Set_Event_Filter with the following
                    parameters:
                    <table>
                    <tr><td> 0x02 - Connection  setup filter type
                    <tr><td> 0x00 - Allow connections from all devices
                    <tr><td> 0x02 - Auto accept the connection
                    </table>

*************************************************************************************/
TESTENGINE_API(int) dmSetEventFilterAutoacceptConnection(uint32 handle);

/*******************************************************************************
 
  Function Name :   int bccmdBc3PsuTrim(uint32 aHandle, uint16 aData)

  Parameters :      aHandle - A valid BlueCore device handle.
  
                    aData - Data to send with the PDU.

  Returns :         -1 on an invalid device handle, 1 on success, otherwise
                    0 on failure.

  Description :     This function will write a BCCMD with VARID of
                    BCCMDVARID_BC3PSU and a function of BCCMDPDU_BC3PSU_PSU_TRIM
                    to the connected BlueCore device.

*******************************************************************************/
TESTENGINE_API(int) bccmdBc3PsuTrim(uint32 aHandle, uint16 aData);

/*******************************************************************************
 
  Function Name :   int bccmdBc3BuckReg(uint32 aHandle, uint16 aData)

  Parameters :      aHandle - A valid BlueCore device handle.
  
                    aData - Data to send with the PDU.

  Returns :         -1 on an invalid device handle, 1 on success, otherwise
                    0 on failure.

  Description :     This function will write a BCCMD with VARID of
                    BCCMDVARID_BC3PSU and a function of BCCMDPDU_BC3PSU_BUCK_REG
                    to the connected BlueCore device.

*******************************************************************************/
TESTENGINE_API(int) bccmdBc3BuckReg(uint32 aHandle, uint16 aData);

/*******************************************************************************
 
  Function Name :   int bccmdBc3MicEn(uint32 aHandle, uint16 aData)

  Parameters :      aHandle - A valid BlueCore device handle.
  
                    aData - Data to send with the PDU.

  Returns :         -1 on an invalid device handle, 1 on success, otherwise
                    0 on failure.

  Description :     This function will write a BCCMD with VARID of
                    BCCMDVARID_BC3PSU and a function of BCCMDPDU_BC3PSU_MIC_EN
                    to the connected BlueCore device.

*******************************************************************************/
TESTENGINE_API(int) bccmdBc3MicEn(uint32 aHandle, uint16 aData);

/*******************************************************************************
 
  Function Name :   int bccmdBc3Led0(uint32 aHandle, uint16 aData)

  Parameters :      aHandle - A valid BlueCore device handle.
  
                    aData - Data to send with the PDU.

  Returns :         -1 on an invalid device handle, 1 on success, otherwise
                    0 on failure.

  Description :     This function will write a BCCMD with VARID of
                    BCCMDVARID_BC3PSU and a function of BCCMDPDU_BC3PSU_LED0
                    to the connected BlueCore device.

*******************************************************************************/
TESTENGINE_API(int) bccmdBc3Led0(uint32 aHandle, uint16 aData);

/*******************************************************************************
 
  Function Name :   int bccmdBc3Led1(uint32 aHandle, uint16 aData)

  Parameters :      aHandle - A valid BlueCore device handle.
  
                    aData - Data to send with the PDU.

  Returns :         -1 on an invalid device handle, 1 on success, otherwise
                    0 on failure.

  Description :     This function will write a BCCMD with VARID of
                    BCCMDVARID_BC3PSU and a function of BCCMDPDU_BC3PSU_LED1
                    to the connected BlueCore device.

*******************************************************************************/
TESTENGINE_API(int) bccmdBc3Led1(uint32 aHandle, uint16 aData);

/*******************************************************************************
 
  Function Name : int hciCreateConnectionNoWait(uint32 aHandle, uint32 aLap, uint8 aUap, uint16 aNap, uint16 aPktType, uint8 aPageScanRepMode, uint8 aPageScanMode, uint16 aClockOffset, uint8 aAllowRoleSwitch)

  Parameters :    aHandle - A valid BlueCore device handle.

                  aLap - The LAP portion of the Bluetooth address of the device
                      to request a connection with.

                  aUap - The UAP portion of the Bluetooth address of the device
                      to request a connection with.

                  aNap - The NAP portion of the Bluetooth address of the device
                      to request a connection with.

                  aPktType - Bitwise Or-ed combination of packet types as
                      defined in the  Bluetooth specification.
                      <table>
                      <tr><td> HCI_PKT_DM1 ((uint16)0x0008) SCO and ACL
                      <tr><td> HCI_PKT_DH1 ((uint16)0x0010) ACL only
                      <tr><td> HCI_PKT_DM3 ((uint16)0x0400) ACL only
                      <tr><td> HCI_PKT_DH3 ((uint16)0x0800) ACL only
                      <tr><td> HCI_PKT_DM5 ((uint16)0x4000) ACL only
                      <tr><td> HCI_PKT_DH5 ((uint16)0x8000) ACL only
                      </table>
                   
                  aPageScanRepMode - The page scan repetition mode supported
                      by the remote device with the given Bluetooth address.
                  
                  aPageScanMode - Indicates the page scan mode that is used
                      for default page scan.
                  
                  aClockOffset - Difference between the clocks of the local
                      device and the remote device with the given Bluetooth
                      address.
                                          
                  aAllowRoleSwitch - Specifies whether the local device
                      accepts or rejects the request of master-slave role
                      switch.

  Returns :       -1 on an invalid device handle, 1 on success, otherwise
                  0 on failure.

  Description :   This function can be used to request a connection with a
                  given device.<br>
                  It is similar to the hciCreateConnectionNoInquiry function,
                  the difference being that this function does not wait for
                  a 'Command Complete' or a 'Connection Complete' event.<br>
                  This is useful for creating connections involving encryption
                  and link-key requests where other operations need to be
                  performed before these events are generated.

*******************************************************************************/
TESTENGINE_API(int) hciCreateConnectionNoWait(uint32 aHandle, uint32 aLap, uint8 aUap, uint16 aNap, uint16 aPktType, uint8 aPageScanRepMode, uint8 aPageScanMode, uint16 aClockOffset, uint8 aAllowRoleSwitch);

/*******************************************************************************
 
  Function Name : int hciWriteAuthenticationEnable(uint32 aHandle, uint8 aEnable)

  Parameters :    aHandle - A valid BlueCore device handle.

                  aEnable - Set to 1 when authentication required for
                      connections, otherwise 0.

  Returns :       -1 on an invalid device handle, 1 on success, otherwise
                  0 on failure.

  Description :   This function will write the value for the
                  Authentication_Enable configuration parameter.

*******************************************************************************/
TESTENGINE_API(int) hciWriteAuthenticationEnable(uint32 aHandle, uint8 aEnable);

/*******************************************************************************
 
  Function Name : int hciLinkKeyRequestNegativeReply(uint32 aHandle, uint32 aLap, uint8 aUap, uint16 aNap)

  Parameters :    aHandle - A valid BlueCore device handle.

                  aLap - The LAP portion of the Bluetooth address of the device
                      that there is no stored link key for.

                  aUap - The UAP portion of the Bluetooth address of the device
                      that there is no stored link key for.

                  aNap - The NAP portion of the Bluetooth address of the device
                      that there is no stored link key for.

  Returns :       -1 on an invalid device handle, 1 on success, otherwise
                  0 on failure.

  Description :   This function is used to reply to a Link Key Request from the
                  controller if the local device does not have a stored link
                  key for the device with the given Bluetooth address.

*******************************************************************************/
TESTENGINE_API(int) hciLinkKeyRequestNegativeReply(uint32 aHandle, uint32 aLap, uint8 aUap, uint16 aNap);

/*******************************************************************************
 
  Function Name : int hciWaitForConnectionComplete(uint32 aHandle, uint16* aConnHandle)

  Parameters :    aHandle - A valid BlueCore device handle.

                  aConnHandle - Connection handle of the device if successful.
                      Set to 0xffff on failure.

  Returns :       -1 on an invalid device handle, 1 on success, otherwise
                  0 on failure.

  Description :   This function is used to wait for a 'Connection Complete'
                  event.<br>
                  If the event is not triggered within 2 seconds of 
                  invocation it will return failure and the value of the 
                  aConnHandle parameter will be set to 0xffff.

*******************************************************************************/
TESTENGINE_API(int) hciWaitForConnectionComplete(uint32 aHandle, uint16* aConnHandle);

/*******************************************************************************
 
  Function Name : int hciWaitForLinkKeyRequest(uint32 aHandle, uint32* aLap, uint8* aUap, uint16* aNap)

  Parameters :    aHandle - A valid BlueCore device handle.

                  aLap - The LAP portion of the Bluetooth address of the device
                      for which a stored link key is being requested.

                  aUap - The UAP portion of the Bluetooth address of the device
                      for which a stored link key is being requested.

                  aNap - The NAP portion of the Bluetooth address of the device
                      for which a stored link key is being requested.

  Returns :       -1 on an invalid device handle, 1 on success, otherwise
                  0 on failure.

  Description :   This function can be used to wait for a 'Link Key Request'
                  event. A link key request event will be generated when setting
                  up a connection when authentication has been enabled (see
                  hciWriteAuthenticationEnable) prior to calling
                  hciCreateConnectionNoWait.<br>
                  If the event is not triggered within 2 seconds of 
                  invocation it will return failure.

*******************************************************************************/
TESTENGINE_API(int) hciWaitForLinkKeyRequest(uint32 aHandle, uint32* aLap, uint8* aUap, uint16* aNap);

/*******************************************************************************
 
  Function Name : int hciWaitForPinCodeRequest(uint32 aHandle, uint32* aLap, uint8* aUap, uint16* aNap)

  Parameters :    aHandle - A valid BlueCore device handle.

                  aLap - The LAP portion of the Bluetooth address of the device
                      which a new link key is being created for.

                  aUap - The UAP portion of the Bluetooth address of the device
                      which a new link key is being created for.

                  aNap - The NAP portion of the Bluetooth address of the device
                      which a new link key is being created for.

  Returns :       -1 on an invalid device handle, 1 on success, otherwise
                  0 on failure.

  Description :   This function can be used to wait for a 'PIN Code Request'
                  event. A PIN code request event will be generated when setting
                  up a connection when authentication has been enabled (see
                  hciWriteAuthenticationEnable) prior to calling
                  hciCreateConnectionNoWait.<br>
                  The recipient must respond by calling hciPinCodeRequestReply.
                  <br>If the event is not triggered within 2 seconds of 
                  invocation it will return failure.

*******************************************************************************/
TESTENGINE_API(int) hciWaitForPinCodeRequest(uint32 aHandle, uint32* aLap, uint8* aUap, uint16* aNap);

/*******************************************************************************
 
  Function Name : int hciWaitForEncryptionChange(uint32 aHandle, uint8* aEnable)

  Parameters :    aHandle - A valid BlueCore device handle.

                  aEnable - Defines whether encryption is enabled/disabled.

  Returns :       -1 on an invalid device handle, 1 on success, otherwise
                  0 on failure.

  Description :   This function can be used to wait for an 'Encryption Change'
                  event. An encryption change event will be generated following
                  a call to hciSetConnectionEncryption. The event will be
                  generated for both devices on the connection<br>
                  If the event is not triggered within 2 seconds of 
                  invocation it will return failure.

*******************************************************************************/
TESTENGINE_API(int) hciWaitForEncryptionChange(uint32 aHandle, uint8* aEnable);

/*******************************************************************************
 
  Function Name : int hciPinCodeRequestReply(uint32 aHandle, uint32 aLap, uint8 aUap, uint16 aNap, uint8 aPinCodeLength, uint8* aPinCode)

  Parameters :    aHandle - A valid BlueCore device handle.

                  aLap - The LAP portion of the Bluetooth address of the device
                     for which the PIN code is for.

                  aUap - The UAP portion of the Bluetooth address of the device
                     for which the PIN code is for.

                  aNap - The NAP portion of the Bluetooth address of the device
                     for which the PIN code is for.

                  aPinCodeLength - The length (in bytes) of the PIN code to
                      be used. Range 1 - 16.

                  aPinCode - PIN code for the device that is to be connected.
                      This should be an array of bytes equal in length to the
                      given aPinCodeLength parameter.

  Returns :       -1 on an invalid device handle, 1 on success, otherwise
                  0 on failure.

  Description :   This function can be used to respond to a 'PIN Code Request'
                  event (see hciWaitForPinCodeRequest) and specifies the PIN
                  code to use for a connection.

*******************************************************************************/
TESTENGINE_API(int) hciPinCodeRequestReply(uint32 aHandle, uint32 aLap, uint8 aUap, uint16 aNap, uint8 aPinCodeLength, uint8* aPinCode);

/*******************************************************************************
 
  Function Name : int hciSetConnectionEncryption(uint32 aHandle, uint16 aConnHandle, uint8 aEnable)

  Parameters :    aHandle - A valid BlueCore device handle.

                  aConnHandle - Connection handle to enable/disable link layer
                      encryption.

                  aEnable - Set to 1 to enable link layer encryption, otherwise
                      set to 0.

  Returns :       -1 on an invalid device handle, 1 on success, otherwise
                  0 on failure.

  Description :   This function can be used to enable or disable link level
                  encryption.

*******************************************************************************/
TESTENGINE_API(int) hciSetConnectionEncryption(uint32 aHandle, uint16 aConnHandle, uint8 aEnable);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __INCTestEngineh */
