#ifndef __INCTestPSh
#define __INCTestPSh

#define TESTPS_API(T) T _stdcall

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/*************************************************************************************
	
	Function Name :	int open_ps(int port, int device);

	Parameters :
					port - Number refering to the LPT port to be used

					device - Number refering to the device to be communicated with, 0 
						to 15 refering to the port on the CSR gang programmer. If the 
						gang programmer is not used then this should be set to 0.

	Returns :		non-zero on success, 0 on failure.

	Description :	<i> 
                    Use of persistent store functions in TestFlash are deprecated and 
                    may disappear in a future release.
                    The persistent store functions in TestEngine should be used instead,
                    using initTestEngineSpi to create a connection.</i><p>
                    This function is used to create the appropriate host side objects 
					to enable PS reads and writes via the SPI or gang programming 
					interface. This function will have absolute control of the SPI 
					interface so care should be taken that the interface has not been 
					allocated elsewhere, for example by init_flash(..).

*************************************************************************************/
TESTPS_API(int) open_ps(int port, int device);

/*************************************************************************************
	
	Function Name :	int close_ps();

	Parameters :	
                    none

	Returns :		1.

	Description :	<i> 
                    Use of persistent store functions in TestFlash are deprecated and 
                    may disappear in a future release.
                    The persistent store functions in TestEngine should be used instead,
                    using initTestEngineSpi to create a connection.</i><p>
                    This function is used to free any objects associated with open_ps().

*************************************************************************************/
TESTPS_API(int) close_ps(void);

#define	PS_STORES_DEFAULT (0x0000)	/* default */
#define	PS_STORES_I       (0x0001)	/* implementation (normal) */
#define	PS_STORES_F       (0x0002)	/* factory-set */
#define	PS_STORES_R       (0x0004)	/* rom (read-only) */
#define	PS_STORES_T       (0x0008)	/* transient (RAM) */


/*************************************************************************************
	
	Function Name :	void set_stores(const uint16 store);

	Parameters :	
                    store - bit mask to identify the PS store layer to write to. See 
					        comments above under PS_STORES.

	Returns :		none

	Description :	<i> 
                    Use of persistent store functions in TestFlash are deprecated and 
                    may disappear in a future release.
                    The persistent store functions in TestEngine should be used instead,
                    using initTestEngineSpi to create a connection.</i><p>
                    Sets the PS store to access.

*************************************************************************************/
TESTPS_API(void) set_stores(const unsigned short store);

/*************************************************************************************
	
	Function Name :	int write_ps(const unsigned short key, const unsigned short *const data, const uint16 len );

	Parameters :	
                    key - The PS key entry id.

					data - Pointer to an array holding the PS data to be written.
					
					len - The size of the array of PS data.

	Returns :		0 on fail, 1 on success

	Description :	<i> 
                    Use of persistent store functions in TestFlash are deprecated and 
                    may disappear in a future release.
                    The persistent store functions in TestEngine should be used instead,
                    using initTestEngineSpi to create a connection.</i><p>
                    This function is used to write to the persistent store.

*************************************************************************************/
TESTPS_API(int) write_ps(const unsigned short key, const unsigned short *const data, const unsigned short len );

/*************************************************************************************
	
	Function Name :	int write_ps_verify(const unsigned short key, const unsigned short *const data, const uint16 len );

	Parameters :	
                    key - The PS key entry id.

					data - Pointer to an array holding the PS data to be written.
					
					len - The size of the array of PS data.

	Returns :		0 on fail, 1 on success, i.e. the key was veriffied as written.

	Description :	<i> 
                    Use of persistent store functions in TestFlash are deprecated and 
                    may disappear in a future release.
                    The persistent store functions in TestEngine should be used instead,
                    using initTestEngineSpi to create a connection.</i><p>
                    This function is used to write and subsequenlty read and compare the persistent store.
                   Prior to calling this, you could call set_stores with a bit pattern incorporating either 
                   PS_STORES_I or PS_STORES_F, but the default for the stores 
                   being (PS_STORES_I | PS_STORES_F | PS_STORES_R) means 
					you need not worry about calling set_stores.

*************************************************************************************/
TESTPS_API(int) write_ps_verify(const unsigned short key, const unsigned short *const data, const unsigned short len );

/*************************************************************************************
	
	Function Name :	int read_ps(const unsigned short key, unsigned short *const data, const unsigned short maxlen, unsigned short * const len );

	Parameters :	
                    key - The PS key entry id.

					data - Pointer to an array to recieve the PS data to be read.
					
					maxlen - The size of the data array

					len - The acrual size of the read key

	Returns :		0 on fail, 1 on success

	Description :	<i> 
                    Use of persistent store functions in TestFlash are deprecated and 
                    may disappear in a future release.
                    The persistent store functions in TestEngine should be used instead,
                    using initTestEngineSpi to create a connection.</i><p>
                    This function is used to write to the persistent store.

*************************************************************************************/
TESTPS_API(int) read_ps(const unsigned short key, unsigned short *const data, const unsigned short maxlen, unsigned short * const len );

/*************************************************************************************
	
	Function Name :	int clear_ps(const pskey key);

	Parameters :	
                    key - The PS key entry id.

	Returns :		0 on fail, 1 on success

	Description :	<i> 
                    Use of persistent store functions in TestFlash are deprecated and 
                    may disappear in a future release.
                    The persistent store functions in TestEngine should be used instead,
                    using initTestEngineSpi to create a connection.</i><p>
                    This function is used to clear a persistent store entry.

*************************************************************************************/
TESTPS_API(int) clear_ps(const unsigned short key);

/*************************************************************************************
	
	Function Name :	int factory_set(void)

	Parameters :	
                    none

	Returns :		0 on fail, 1 on success

	Description :	<i> 
                    Use of persistent store functions in TestFlash are deprecated and 
                    may disappear in a future release.
                    The persistent store functions in TestEngine should be used instead,
                    using initTestEngineSpi to create a connection.</i><p>
                    This function is used to move PS values to the factory layer.

*************************************************************************************/
TESTPS_API(int) factory_set(void);

/*************************************************************************************
	
	Function Name :	int e2_device(const unsigned short log2bytes, const unsigned short addrmask)

	Parameters :	
                    log2bytes - Size of the EEPROM device specified in log2 bytes.
                                (e.g. 8Kbit device = 10)

                    addrmask - EEPROM device address.

	Returns :		0 on fail, 1 on success

	Description :	<i> 
                    Use of this function is deprecated. Use the EEPROM utility
                    API (e2api) for programming EEPROM devices.</i><p>
                    This function is used to detect an EEPROM device connected
                    to the BlueCore.
                    <p>Before this function can be used a SPI connection must be
                    created with a call to open_ps.

*************************************************************************************/
TESTPS_API(int) e2_device(const unsigned short log2bytes, const unsigned short addrmask);

/*************************************************************************************
	
	Function Name :	int get_firmware_id(int *const id, unsigned short *nameBuffer, const unsigned int length)

	Parameters :	
	                id - Pointer to a location to take the firmware ID.

                    nameBuffer - Pointer to a preallocated array of size given 
					   by the length parameter.

                    length - Length of the given name buffer.

	Returns :		0 on fail, 1 on success

	Description :	This function is used to retrieve the firmware ID of the
                    connected BlueCore device.
					<p>Before this function can be used a SPI connection must be
					created with a call to open_ps.

*************************************************************************************/
TESTPS_API(int) get_firmware_id(int *const id, unsigned short *nameBuffer, const unsigned int length);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __INCTestPSh */
